package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See L<http://www.perl.com/perl/misc/Artistic.html>

=cut


__DATA__
M?T5,1@$"`0`````````````#`!0````!```9Y````#0``0&````````T`"``
M"``H`!P`&P````8````T````-````#0```$````!``````4````$`````P``
M`30```$T```!-`````T````-````!`````$````!``````````````````"6
M!```E@0````%``$```````$``/R```'\@``!_(````/L```4!`````8``0``
M`````@``_<P``?W,``']S````2@```$H````!@````0````$```!1````40`
M``%$````1````$0````$````!&1TY5$`````````````````````````````
M``8````09'3E4@``_(```?R```'\@````X````.`````!`````$O;&EB+VQD
M+G-O+C$`````````!````!`````!1TY5```````````#`````@`````````$
M````%`````-'3E4`GY(@T9CJP]:=M5&%3T?K+7'R=4,````1````3@````@`
M```(!!`0`(`$0"4````H@`"&H````8`)!"@+11*@.`@(!(H`````````3@``
M`%(```!6````5P```%T```!>````7P```&$```!B`````````&0```!E````
M9@```&<``````````!_?Q6X.[]/J+4?>SGR:?VNVF\4N#N3_(`[QC;A\U&35
M'%AQV0'&1^+`XTNL?)+CNBP_Y<)@;*'Z;XL!L]9#"6MFS*]G[-5%0M-P!XF>
MXA0-GN/-VNW;8C,+ESH-FYRI?PH"I^%)^^"C````````````````````````
M`````!<\``````,```L```+%```````````2```````#<P``````````$@``
M`````A,``````````!(````````1```````````@```````#C```````````
M$0``````!````````````!(```````,2```````````1```````#9```````
M````$@```````24``````````!(```````+@```````````2````````R```
M````````$@```````9<``````````!(```````+,```````````2````````
MF```````````$@```````2```````````!(```````.6```````````2````
M```#&0``````````$@```````14``````````!$```````*-```````````2
M```````!>P``````````$@```````/<``````````!$```````,@````````
M```2```````!20``````````$@```````-8``````````!(```````-'````
M```````B```````!Q0``````````$@```````EP``````````!(```````(+
M```````````2```````"J0``````````$@```````;(``````````!(`````
M``*:```````````2```````!O@``````````$@```````5<``````````!(`
M``````,I```````````2````````+0``````````(````````FX`````````
M`!(```````'0```````````1```````#-@``````````$@```````'@`````
M`````!(```````*W```````````2```````#>@``````````$@```````@0`
M`````````!(```````"G```````````2```````#5@``````````$@``````
M`+,``````````!(```````%P```````````2```````"O@``````````$@``
M`````I0``````````!(```````)[```````````2```````!-@``````````
M$@```````BP``````````!(```````*B```````````2````````:@``````
M````$@```````2H``````````!(```````+G```````````2```````!IP``
M````````$@```````M(``````````!(```````$$```````````2```````#
M;```````````$@```````K```````````!(```````.-```````````A````
M```!B0``````````$@```````(<``````````!(````````\```````````@
M````````Z```````````$@```````6<``````````!(```````,]````````
M```2````````4```````````(````````G,``````````!(```````..````
M```````1```````#"```````````$@```````A@``````````!(```````+U
M```````````2```````"/0``````````$@```````H0``````````!(`````
M``,````````````2```````$"0``3/````#T$@``#````]<``%2@`````!(`
M``T```0N```]T```"Q02```,```#AP``%X````)D$@``#````]T``#10````
M&!(```P```2-```T<````FP2```,```$AP``%SP`````$@``"P``!+H``$CP
M```$`!(```P```.\``(`;``````0```9```$%0``-N````!8$@``#````DT`
M`%3,````!!$```X```/(``(0A``````0```9```$A0``,J````!0$@``#```
M!)H``#PP```!G!(```P```2L```[$````,`2```,```$.P`"`!``````$```
M%P``!"(``#=````!V!(```P```.U``(`;``````0```8```$;@`"`&@````$
M$0``&````\T``$\@````&!(```P```1>``!.8````,`2```,```$00``&>0`
M```T$@``#```!#T``@`0`````"```!<```/N```[T````%@2```,```$2```
M,V````#L$@``#```!'@``#D@```!Y!(```P`;&EB<&5R;"YS;RXU+C(T`%])
M5$U?9&5R96=I<W1E<E1-0VQO;F5486)L90!?7V=M;VY?<W1A<G1?7P!?2G9?
M4F5G:7-T97)#;&%S<V5S`%])5$U?<F5G:7-T97)434-L;VYE5&%B;&4`4&5R
M;%]S>7-?=&5R;0!097)L7W-Y<U]I;FET,P!097)L7V%T9F]R:U]L;V-K`'!E
M<FQ?8V]N<W1R=6-T`%!E<FQ?9V5T7W-V`%!E<FQ?8W)O86M?;F]C;VYT97AT
M`%!E<FQ?879?<VAI9G0`4&5R;%]S=E\R<'9?9FQA9W,`4&5R;%]S=E]S971P
M=FX`4$Q?9&]?=6YD=6UP`%!E<FQ?;F5W6%-?9FQA9W,`4$Q?=&AR7VME>0!P
M97)L7V9R964`4&5R;%]M9U]S970`4&5R;%]A=&9O<FM?=6YL;V-K`%!E<FQ?
M<W9?<V5T<'8`4&5R;%]G=E]F971C:'!V`'!E<FQ?<G5N`%!E<FQ?;F5W6%,`
M<&5R;%]D97-T<G5C=`!097)L7V%V7V9E=&-H`&)O;W1?1'EN84QO861E<@!P
M97)L7W!A<G-E`%!E<FQ?<V%F97-Y<VUA;&QO8P!P97)L7V%L;&]C`%!,7VUE
M;6]R>5]W<F%P`&QI8F1L+G-O+C(`;&EB;2YS;RXV`&QI8G!T:')E860N<V\N
M,`!O<&5N-C0`;'-E96LV-`!R96%D`'!T:')E861?9V5T<W!E8VEF:6,`7U]E
M<G)N;U]L;V-A=&EO;@!C;&]S90!L:6)C+G-O+C8`7TE/7W-T9&EN7W5S960`
M7U]R96=I<W1E<E]A=&9O<FL`97AI=`!S=')N8VUP`%]?<W1R9'5P`&-L;W-E
M9&ER`'5N;&EN:P!M:V1I<@!R96%L;&]C`&UE;6-H<@!G971P:60`<W1R=&]K
M`'-T<FQE;@!M96US970`<W1R<W1R`')M9&ER`%]?9G!R:6YT9E]C:&L`;65M
M8W!Y`%]?<W1R;F-P>5]C:&L`7U]L>'-T870V-`!O<&5N9&ER`%]?>'-T870V
M-`!S=&1E<G(`9V5T=6ED`')E861L:6YK`%]?;65M8W!Y7V-H:P!S=')C:'(`
M<F5A9&1I<C8T`%]?8WAA7V9I;F%L:7IE`%]?<W!R:6YT9E]C:&L`;65M;6]V
M90!A8V-E<W,`<W1R8VUP`%]?;&EB8U]S=&%R=%]M86EN`%]?96YV:7)O;@!?
M7W-T86-K7V-H:U]F86EL`&QI8F-R>7!T+G-O+C$`7V5D871A`%]?8G-S7W-T
M87)T`%]E;F0`7U]L:6)C7V-S=5]F:6YI`'!A<E]C=7)R96YT7V5X96,`9V5T
M7W5S97)N86UE7V9R;VU?9V5T<'=U:60`<&%R7V-L96%N=7``<&%R7V)A<V5N
M86UE`'!A<E]D:7)N86UE`'!A<E]M:W1M<&1I<@!?7V1A=&%?<W1A<G0`<&%R
M7V-U<G)E;G1?97AE8U]P<F]C`%]?;&EB8U]C<W5?:6YI=`!M>5]P87)?<&P`
M<&%R7VEN:71?96YV`'AS7VEN:70`<&%R7V9I;F1P<F]G`'!A<E]S971U<%]L
M:6)P871H`'!A<E]E;G9?8VQE86X`6%-?26YT97)N86QS7U!!4E]"3T]4`$=,
M24)#7S(N,@!'3$E"0U\R+C``1TQ)0D-?,BXS+C0`1TQ)0D-?,BXS+C(`1TQ)
M0D-?,BXQ+C,`1TQ)0D-?,BXT`````````@`"``,````"``(``@`"``(``@``
M`````@``````!``"`````@```````@``````!0````8`!P`"`````@`"````
M"`````(````"`````@`"``<````$```````"``(``@````,``@``````"```
M``0````"``(``@``````````````"0````(``@`)``,`"0`#``(``@`!``$`
M`0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!
M``$````!``(```'T````$````#`-:6D2````!P``!-`````0#6EI$`````,`
M``3:```````!``8```)#````$``````-:6D2````"0``!-`````0"6D9=```
M``@```3D````$`EI&7(````&```$\````!`):1]S````!0``!/P````0#6EI
M%`````0```4(````$`UI:1`````"```$V@```````?R`````%@``&V```?R$
M````%@``&O```?R,````%@`"`&@``?R0````%@`"`&@``?R<````%@`"`&P`
M`?RD````%@`"`!0``?RL````%@`!_(@``?RT````%@`"`'```?RX````%@``
M50```?S`````%@``50@``?S$````%@``5-```?S,````%@``51@``?S0````
M%@``6`@``?S4````%@``2/```?S8````%@``530``?S<````%@``54P``?S@
M````%@``55```?SD````%@``55P``?SH````%@``56```?SL````%@``56P`
M`?SP````%@``57P``?ST````%@``58```?SX````%@``580``?S\````%@``
M58P``?T`````%@``59@``?T$````%@``5:```?T(````%@``5:P``?T,````
M%@``5;0``?T0````%@``5<0``?T4````%@``5=```?T8````%@``5=P``?T<
M````%@``5>@``?T@````%@``5?0``?TD````%@``5@```?TH````%@``5@P`
M`?TL````%@``5B```?TP````%@``5C0``?TT````%@``5D```?TX````%@``
M5E```?T\````%@``5F0``?U`````%@``5G```?U$````%@`"`!@``?U(````
M%@``5G0``?U,````%@``5GP``?U0````%@``5H0``?U4````%@``5HP``?U8
M````%@``5I@``?U@````%@``5M0``?UD````%@``5MP``?UH````%@``5N0`
M`?UL````%@``5O0``?UP````%@``5P0``?UT````%@``6%P``?UX````%@``
M5Q@``?U\````%@``5VP``?V`````%@``5W0``?V$````%@``5W@``?V(````
M%@``5X```?V,````%@``5X0``?V0````%@``5YP``?V4````%@``5Z0``?V8
M````%@``5\@``?VL````%@``5O```?VP````%@``6`P``?VT````%@`"`&@`
M`?VX````%@``6!```?V\````%@``,O```?W`````%@`"`!0``?W$````%@`!
M_(0``?W(````%@`!_(```@``````%@`!_O@``@`$````%@``%X```@`(````
M%@``3F```@`,````%@``3R```@`4````%@`"`!0``@`<````%@``6#P``@`@
M````%@``6$P``@`D````%@``6%0``@`H````%@``6%P``@`L````%@``6&0`
M`@`P````%@``6'@``@`X````%@``6#0``@`\````%@``55P``@!$````%@``
M5C0``@!(````%@``5C@``@!,````%@``6"@``@!0````%@``560``@!4````
M%@``6#```@!<````%@``6!0``@!@````%@``6!P``@!H````%@``6(0``?R4
M```%`0```````?R8``!%`0```````?R@```:`0```````?RH``!!`0``````
M`?RP``!'`0```````?R\```3`0```````?S(```-`0```````?U<```(`0``
M`````?V<```S`0```````?V@``!``0```````?VD```6`0```````?VH```F
M`0```````?[T```D%````````?\$```"%0```````?\(```#%0```````?\,
M```$%0```````?\0```'%0```````?\4```)%0```````?\8```*%0``````
M`?\<```+%0```````?\@```,%0```````?\D```.%0```````?\H```/%0``
M`````?\L```0%0```````?\P```1%0```````?\T```2%0```````?\X```4
M%0```````?\\```5%0```````?]````7%0```````?]$```8%0```````?](
M```9%0```````?],```:%0```````?]0```;%0```````?]4```<%0``````
M`?]8```=%0```````?]<```>%0```````?]@```?%0```````?]D```@%0``
M`````?]H```A%0```````?]L```B%0```````?]P```C%0```````?]T```D
M%0```````?]X```E%0```````?]\```G%0```````?^````H%0```````?^$
M```I%0```````?^(```J%0```````?^,```K%0```````?^0```L%0``````
M`?^4```M%0```````?^8```N%0```````?^<```O%0```````?^@```P%0``
M`````?^D```Q%0```````?^H```R%0```````?^L```T%0```````?^P```U
M%0```````?^T```V%0```````?^X```W%0```````?^\```X%0```````?_`
M```Y%0```````?_$```Z%0```````?_(```[%0```````?_,```\%0``````
M`?_0```]%0```````?_4```_%0```````?_8``!"%0```````?_<``!#%0``
M`````?_@``!$%0```````?_D``!&%0```````?_H``!(%0```````?_L``!)
M%0```````?_P``!*%0```````?_T``!+%0```````?_X``!,%0```````?_\
M``!-%0````"4(?_P?`@"II`!`!23P0`(0I\`!7_(`J8_W@`".][GJ(`>__PO
M@```0;X`"$@`.<F``0`4?`@#IH/!``@X(0`03H``()0A_\!\"`*F0I\`!9/!
M`#B0`0!$?\@"II.A`#2080`<D($`&)"A`!23@0`PD^$`/#B!`!@XH0`4.&$`
M'#_>``([WF4D@2*/^)$A`"PY(```2``YD8"^@.R`?H#P?*0K>$@`-A&!/H#T
MBZD``"^=``!!G@%D@_Z`#(!_``!(`#L5B2,$YGQJ&WB`?P``82D``IDJ!.9(
M`#K]@2$`'#U`/_]A2O__.2D`!8D#!.9_B5!`80H``9E#!.9!G0%L52,0.D@`
M.*&!/H$$@4$`&("A`!R#_H`$@2D``($*``!\:QMX+X4``3SE0`"1(P`(@3Z!
M")$#``"!'H$`D2,`##D@``20?Q`(D0,`!)$_$`1`G0`P5.D0.CD#``PY*?_X
M52GPOCDI``%]*0.F8````&````"%*@`$E2@`!$(`__@XYP`#@)Z!#(!_$!`Y
M0```5.D0.GUF6W@XX```.*4``WU+22Y(`#F!?'T;>4&"`)B`?Q`0.X$`*$@`
M-UV`?H!@?X3C>$S&,8)(`!#=+X,``$&>`(2`?Q`02``V_4@`.1E_H^MX@4$`
M+($BC_A]2DIY.2```$""`*B``0!$@X$`,(.A`#2#P0`X?`@#IH/A`#PX(0!`
M3H``($@`-TV!7H`$+X,``)!J$!!!G@!X2``VF8/^@`R`?P``2``YG9NC!U5+
M__Y\@'\0$$@`.4U\?1MX2___8(!_$`PO@P``09X`'$@`,U5+__]P@)Z`^(!^
M@/Q,QC&"2``X$8!^@#A_A.-X3,8Q@D@`$"$O@P``D'\0#$&>_T1(`#,A2___
M/$@`-6DX8``!2``W87PI"WA4(0`V0I\`!7VH`J8X````E"'_\'P(`Z:0`0``
M/\T``CT-``([WN4(A:CF$$@`-VP``````````)0A__!\"`*F0I\`!9/!``B0
M`0`4?\@"IC_>``([WF)@@3Z``(!^@`0Y*0`#?2-(4"N)``9`G0`8@3Z`""^)
M``!!G@`,?2D#IDZ`!"&``0`4@\$`"#@A`!!\"`.F3H``()0A__!\"`*F0I\`
M!9/!``B0`0`4?\@"IC_>``([WF(`@'Z`!(">@`!\@R!0?(06<'R$#G!\A`&5
M08(`&($^@`POB0``09X`#'TI`Z9.@`0A@`$`%(/!``@X(0`0?`@#IDZ``"!@
M````8````&````"4(?_P?`@"ID*?``63P0`(D`$`%'_(`J:3X0`,/]X``CO>
M89"#_H`0B3\``"^)``!`G@`H@3Z`%"^)``!!G@`0@3Z`&(!I``!(`#592__^
MY3D@``&9/P``@`$`%(/!``B#X0`,."$`$'P(`Z9.@``@E"'_\'P(`J9"GP`%
MD\$`")`!`!1_R`*F/]X``CO>82"!/H`@?2-+>($C```OB0``0)X`((`!`!2#
MP0`(."$`$'P(`Z9+__[<8````&````"!/H`<+XD``$&>_]Q]*0.F3H`$(4O_
M_]````````````````````````````````"4(?U`.4,`,'P(`J8Y````D`$"
MQ)-!`JB380*LDX$"L).A`K23P0*XD^$"O#DA`!B`XH_XD.$"G#C@```XX``(
M?.D#ID@``!Q@````8````&````!@````8````&````"$R@`(D0D``)$)``B`
MZ@`$D,D`!#DI`!"0Z?_\0@#_Y#D@`$`XX0`0?2D#IC@```!\ZCMX@2<`=(3'
M``B`J@!,@0H`<(%J`$B`B@`<?2DJ>(%*`!B`IP`$?0A:>)`'`(!]*2)X?0A2
M>'TI*GA]"#)X528/_E4J"#Q\R3-X40D(/'U)2WB1)P"$0@#_J(`#``2`PP`,
M/2!:@H%C`!2`HP`<82EYF8-#``"!0P`(5`<N_E3,\+Z!`0`<@(,`)'S\.WA4
M'R@T4UPH-%3'\`)]"$@4?7TJ>%%,\`)]""`4@4$`)'SL8WA_Y^-X?[\P.'T'
M0!1__RIX?6=B>'T(^!1\YP`X@^$`+'U*2!14&_"^?.=:>%0=\`)36_`"?4HH
M%'^[VWA]2C@450<H/GT=V#A]2C@4?9Q`>(#A`#1__T@4?YSK>'^_6!15'_`^
M?1SH%%5=*#Z#@0`\?0CH%'U:^#A_?5!X?.=(%'^]TWA\YV`454KP/GS].!15
M'2@^?1I0.'SGZ!1_[$!X@Z$`1'^<2!1]C--X?WS8%%4<\#Y]#-@45/LH/GT(
MV!1\^N`X@V$`3'U,.'A_O4@4?8S3>'_]^!1_[/@45/WP/E4'*#Y]&N@X?/\X
M%'^,0'A_^T@4?8S3>(-A`%1]7U`451_P/GU,4!14Z"@^?0I`%'SZ^#A_K#AX
M?5M(%(-A`%Q]C--X?4K@%%3G\#Y5'"@^?4Q0%'T:.#A]2N`4?^Q`>(.!`&1_
M>T@4?8S3>'][Z!15'?`^?VS8%%5(*#Y]&T`4?5KH.(-A`&Q\[%!X?YQ(%'V,
MTWA_G/@4?XS@%%5?\#Y5"B@^?1KX.'U<4!1_K$!X@X$`='][2!1]C--X?WLX
M%%4'\#Y_;-@454@H/GT;0!1]6C@X@V$`?'_L4'A_G$@4?8S3>'^<Z!1_C.`4
M55WP/E4**#Y]&N@X?5Q0%'SL0'B#@0"$?WM(%'V,TWA_>_@451_P/G]LV!15
M2"@^?1M`%'U:^#B#80",?ZQ0>'^<2!1]C--X?YPX%'^,X!151_`^50HH/GT:
M.#A]7%`4?^Q`>(.!`)1_>T@4?8S3>'][Z!15'?`^?VS8%%5(*#Y]&T`4?5KH
M.(-A`)Q\[%!X?YQ(%'V,TWA_G/@4?XS@%%5?\#Y5"B@^?1KX.'U<4!1_K$!X
M@X$`I'][2!1]C--X?WLX%%4'\#Y_;-@454@H/GT;0!1]6C@X@V$`K'_L4'A_
MG$@4?8S3>'^\Z!1_K.@455SP/E4**#Y]&N`X?5U0%'SL0'B#H0"T?WM(%'V,
MTWA_^_@455HH/E4;\#Y_[/@4@8$`O']?T!1]2-@X?Y]0>'T]2!1__T-X?0DX
M%(#A`,0](&[955WP/F$IZZ%72B@^?_]`%($!`,Q__U`4?VKJ>'V,2!1]2M)X
M?8S@%%=<\#Y]C%`45^HH/GV,4!1_JN)X?.=(%'U*^GA\Y]@45_OP/GSG4!15
MBB@^?.=0%'^?VGB!00#4?0A(%'T(Z!1__6)X?0CH%%6?\#Z!@0#<5/TH/GT(
MZ!1_??IX?4I(%'^].GA]2N`45/SP/GU*Z!15!R@^?4HX%'_]XGB`X0#D?8Q(
M%'V,V!1_NT)X?8S8%%4=\#Y52"@^?YOJ>'V,0!1\YT@4@0$`['][4GA\Y_@4
M?.?8%%5?\#Y5BB@^?[OZ>'SG4!1]"$@4@4$`]'][8GA]".`4?0C8%%6<\#Z!
M@0#\5/LH/GT(V!1_^^)X?4I(%'][.GA]2N@45/WP/GU*V!15!R@^?4HX%'^;
MZGB`X0$$?8Q(%'][0GA]C/@451_P/GV,V!152"@^?8Q`%'^[^GB!`0$,?.=(
M%'][4GA\Y^`455SP/GSGV!15BB@^?.=0%'_[XGB!00$4?0A(%'][8GA]".@4
M59WP/H&!`1Q]"-@45/LH/GT(V!1_F^IX?4I(%'][.GA]2O@45/_P/GU*V!15
M!R@^?4HX%'^[^GB`X0$D?8Q(%'][0GA]C.`451SP/GV,V!152"@^?8Q`%'_[
MXGB!`0$L?.=(%'][4GA\Y^@455WP/GSGV!15BB@^?.=0%'^;ZGB!00$T?0A(
M%'][8GA]"/@459_P/H&!`3Q]"-@45/LH/GT(V!1_N_IX?4I(%'][.GA]2N`4
M5/SP/GU*V!15!R@^?4HX%'_[XGB`X0%$?8Q(%'][0GA]C.@451WP/GV,V!15
M2"@^?8Q`%'^;ZGB!`0%,?.=(%'][4GA\Y_@455_P/GSGV!15BB@^?.=0%'^[
M^GB!00%4?0A(%'T(X!1_?&)X@V$!7%6,\#Y]".`45/PH/G_Z8GA]".`4?4I(
M%%3\\#Y]2N@4?T<Z>#T@CQMA*;S<?9WC>'U*.!15!R@^?4HX%'V:X#B`X0%D
M?VG8%'^]0#A_^_@450CP/G^]TWA56R@^?[WX%'^?0WA_O=@4?YI`.(-A`6Q\
MZ3@4?_]0.'V'8!152O`^?__3>'T'4WA7NB@^?_]@%(&!`71__]`4?.?H.'T:
M4#A_:=@45[WP/G^;X!1\Y]-X5_LH/GSGX!1]7.MX?.?8%'U:Z#B#80%\?8E@
M%'^<^#A_G--X5__P/GT,0!14^B@^@8$!A'T<0!1_O/MX?0C0%'^<.#A_NO@X
M?VG8%%3G\#Y_G--X?5M0%%4;*#Y]7%`4?_P[>'U*V!1_^C@X@V$!C'V)8!1_
MG$`X?ZSH%%4(\#Z!@0&4?YS3>%5:*#Y_G.@4?/U#>'^<T!1_O5`X?/I`.']I
MV!152O`^?_OX%'^]TWA7FR@^?[WX%'T?4WA_O=@4?1I0.(-A`9Q]B6`4?__@
M.'__TWA7G/`^?.PX%%>Z*#Z!@0&D?/\X%'U?XWA\Y]`4?__H.'U:X#A_:=@4
M5[WP/G__TWA]&T`45/LH/GT?0!1_G^MX?0C8%'^:Z#B#80&L?8E@%'__.#A_
M_]-X5.?P/GU,4!15&B@^@8$!M'U?4!1_OSMX?4K0%'__0#A_NC@X?VG8%%4(
M\#Y_F^`4?__3>%5;*#Y__^`4?/Q#>'__V!1\^D`X@V$!O'V)8!1_G%`X?ZSH
M%%5*\#Z!@0'$?YS3>%?Z*#Y_G.@4?1U3>'^<T!1_O?@X?1I0.']IV!17__`^
M?/LX%'^]TWA7FR@^?[TX%'U'^WA_O=@4?5KX.(-A`<Q]B6`4?.?@.'T,0!17
MG/`^@8$!U'SGTWA7NB@^?.=`%'_HXWA\Y]`4?0CH.'_ZX#A_:=@45[WP/GT(
MTWA]6U`45/LH/GU(4!1_B.MX?4K8%'^:Z#B#80'<?8E@%'T(.#A_[/@45.?P
M/GT(TWA_K#MX?0CX%%5?*#Y]"/@4?[HX.'_IV!1]C%`X@V$!Y%5*\#Y]C--X
M?Y_@%%4?*#Y_C.`4?.Q3>'^<^!1\^E`X?VG8%'V,0#A5'_`^?[OH%($!`>Q]
MC--X5YLH/GV,Z!1]7?MX?8S8%'U:^#B#80'T?[W@.'T)0!17G/`^?0@X%'^]
MTWA_Y^-X?[U`%%6(*#Y_O4`4?_K@.($!`?Q]*=@4?.=@.'SGTWA]25`4/2#*
M8E6,\#YA*<'6?4=0%%>G*#Y_FV)X?4HX%'T)0!2`X0($?0CX%']_ZGA]"/@4
M5[WP/E5?*#Y]F^IX?0CX%'SI.!2#X0(,?WM2>'SGX!1\Y]@455SP/E4**#Y_
MNN)X?.=0%'_I^!2!00(4?UI">'__8!2!@0*,51OP/G__T!14Z"@^?YK:>'__
M0!1]25`4@0$"'']:.GA]2N@4?4K0%%3]\#Y7YR@^?WKJ>'U*.!1]"4`4@.$"
M)']:^GA]".`4?0C0%%?\\#Y57R@^?[KB>'T(^!1\Z3@4@^$"+']:4GA\Y]@4
M?.?0%%5;\#Y5"B@^?YK:>'SG4!1_Z?@4@4$"-']:0GA__^@4?__0%%4=\#Y4
MZ"@^?WKJ>'__0!1]25`4@0$"/'U*X!1_7#IX?4K@%%3Z\#Y7YR@^?[S2>'U*
M.!1]"4`4@.$"1'T(V!1_F_IX?0C8%%?\\#Y57R@^?UOB>'T(^!1\Z3@4@^$"
M3'SGZ!1_?5)X?.?H%%5;\#Y5"B@^?YW:>'SG4!1_Z?@4@4$"5'__T!1_ND)X
M?__0%%4=\#Y4Z"@^?WKJ>'__0!1]25`4@0$"7'U*X!1_7#IX?4K@%%3Z\#Y7
MYR@^?[S2>'U*.!1]"4`4@.$"9'T(V!1_F_IX?0C8%%?\\#Y57R@^?UOB>'T(
M^!1\Z3@4@^$";'SGZ!1_?5)X?.?H%%5;\#Y5"B@^?YW:>'SG4!1_Z?@4@4$"
M='__T!1_ND)X?__0%%4=\#Y4Z"@^?WKJ>'__0!1]25`4@0$"?']:.GA]2N`4
M?4K0%%3\\#Y7YR@^?[KB>'U*.!1]"4`4@.$"A'T(V!1_6_IX?0C8%%?_\#Y5
M6R@^?0C8%'^;^GA\Z3@4?.?H%']]4GB#80*454KP/GSGZ!15'2@^?.?H%'_]
M4GA]B6`4?[U">'V,X!15"/`^?8SH%%3]*#Y]C.@4?5U">'TIV!1]*?@4?[\Z
M>'TI^!15GR@^?2GX%%3G\#X[X```?2D`%'S&8!1\YU@4?0@H%'U*(!20XP`4
MD^,``)$C``23XP`(D,,`#)/C`!"3XP`8D0,`')/C`""10P`D@4$"G(#BC_A]
M2CIY..```$""`"R``0+$@T$"J(-A`JR#@0*P?`@#IH.A`K2#P0*X@^$"O#@A
M`L!.@``@2``E990A_]!\"`*F0I\`!9/!`"B380`<?\@"IGQ[&WF0`0`TDR$`
M%)-!`!B3@0`@DZ$`))/A`"P_W@`".]Y2Q$&"`1"!/H``@TD``"^:``!!G@$`
MB3L``"^)``!!G@#L*XD`/3N@``!!G@`@?WW;>(T]``$NB0``*XD`/4&6``A`
MGO_P?[OH4(/Z```OGP``09X`1'R9(WA_7--X8````&````!_X_MX?Z7K>']D
MVWA(`"AE+X,``$">`!!]/^BN+XD`/4&>`$"'_``$+Y\``$">_]2``0`T?^/[
M>(,A`!2#00`8@V$`''P(`Z:#@0`@@Z$`)(/!`"B#X0`L."$`,$Z``"!_FN!0
M.[T``7^<%G!__^H4DYD``'_C^WB``0`T@R$`%(-!`!B#80`<?`@#IH.!`""#
MH0`D@\$`*(/A`"PX(0`P3H``(#N@``!+__\\.^```$O__X!@````8````&``
M``"4(?_0?`@"ID*?``63H0`DD\$`*'_(`J:3X0`LD`$`-'Q]&W@[X0`8/]X`
M`CO>462!(H_XD2$`'#D@``!_Y/MX?Z/K>$S&,8)+__Y9+X,``$&>`&A@````
M8````&````"!/H``@4$`&($)``!52A`Z?2A2%(#I``0OAP``?.A1+D&>_[Q@
M````8````&````"!20`(E4D`!"^*``!`GO_T?^3[>'^CZWA,QC&"2__]]2^#
M``!`GO^L@4$`'($BC_A]2DIY.2```$""`""``0`T@Z$`)(/!`"B#X0`L."$`
M,'P(`Z9.@``@2``C&6````"4(?^P?`@"ID*?``60`0!4DV$`/).!`$"3H0!$
MD\$`2)/A`$Q_R`*FDN$`+),!`#"3(0`TDT$`.'Q\&W@_W@`".]Y0=(DD``!I
M*0`](2D``($BC_B1(0`<.2```'^D`91_H^MX2``DW3B!`!A\>QMX?X/C>$S&
M,8)+__TY?'\;>4&"`6!(`"2]?YL80$"=`22#00`8@SZ``%=:$#J)/```+XD`
M`$&>`>PKB0`]09X!Y'^#XWA(```48````&`````KB0`]09X`$(TC``$OB0``
M0)[_\'Q\&%`[>P`"@_D``'Q[&A1(`"/M+X,``'Q_T2Y!G@&TB3P``(%!`!B!
M&0``54H0.B^)``!]2%`NF2H``$">`"!(```D8````&````"-/``!G2H``2^)
M``!!G@`,*XD`/4">_^PY(``].[W__YDJ``!@````8````&````"-/0`!G2H`
M`2^)``!`GO_T.&```(%!`!R!(H_X?4I*>3D@``!`@@$X@`$`5(+A`"R#`0`P
M@R$`-'P(`Z:#00`X@V$`/(.!`$"#H0!$@\$`2(/A`$PX(0!03H``(&`````[
MO?__.____V````!@````C3T``9T_``$OB0``0)[_]$O__Y!@````8````&``
M``"#/H``@OD``($W```OB0``09X`J'[HNW@Y0```2```"'_J^WB%*``$.^H`
M`2^)``!`GO_P.4H``U5$$#J!7H`$@2H``"^)``!!G@`X?N.[>$@`(I$O@P``
MD'D``$&>`&A7^A`Z?'@;>#D_``$Y0```52D0.GU822Z3X0`82__^0#D@``%\
M@R-XD2H``$@`(F5\>!MY08(`,%?Z$#I^Y+MX?T73>$@`(/V3&0``2___O#A@
M``!+__Y$.(``"#O@``!+__]\.&#__TO__KQ(`"!EE"'_8'P(`J9"GP`%DX$`
MD)/!`)A_R`*FD`$`I)-!`(B380",DZ$`E)/A`)Q\?!MY/]X``CO>3<2!(H_X
MD2$`?#D@``!!@@`0B3P``"^)``!`G@!`@4$`?($BC_A]2DIY.2```$""`52`
M`0"D@T$`B(-A`(R#@0"0?`@#IH.A`)2#P0"8@^$`G#@A`*!.@``@2``CX7Q]
M&WE!@O^\.V$`$'^CZWA(`"-=+`,``$&"`-2)(P`3(2D`+B^)``!`G@`DB2,`
M%"^)``!!GO_8(2D`+B^)``!!G@#,?2D`T&`````OB0``09[_O#OC`!-_@^-X
M2``AH7QZ&WA_X_MX2``AE7QZ&A0X8P`"2``A&8#>@`A_Z/MX?X?C>#B@__\X
M@``!?'H;>$S&,8)(`"&I?V7;>']$TW@X8``#2``BZ2^#__]_0]-X09X`%($A
M`"!5*00F+XE``$&>`%Q(`"`)?T/3>$@`'X%_H^MX2``BF2P#``!`@O]`8```
M`&````!@````?Z/K>$@`(MU_@^-X2``?A4O__L1@````8````&````")(P`5
M2___/&````!@````2__^44O__ZA(`!ZI8````)0A_^!\"`*F0I\`!9/!`!B0
M`0`D?\@"II.A`!23X0`<?'T;>#_>``([WDP$@_Z`#(!_``!(`"(]?Z3K>#BC
M`4@X8``#2``B/2^#``!!G@`D@`$`)(.A`!0X8```@\$`&(/A`!PX(0`@?`@#
MIDZ``""`?P``2``A_8$C`5A5*00F+XE``$&>`""`?P``2``AY8$C`5A5*00F
M;2K__R^*H`!`GO^P?Z/K>#B```)(`"%%@`$`)(.A`!2#P0`8@^$`'#@A`"!\
M"`.F?&,`-%1CV7Y.@``@8````&````!@````E"'OP#B@#_]\"`*F0I\`!9/!
M$#B381`L?\@"II.!$#"3H1`TD`$01)/A$#Q\?!MX.Z$`''R;(WA_I.MX/]X`
M`CO>2R"`?H`0@2*/^)$A$!PY(```2``>C2P#``!`@0"D.^/__SE!$"!]*OH4
MB2GO_"^)``!!G@!\?'\;>'_E^W@X@``O?Z/K>$@`(!DO@P``09X`<($^@`R`
M:0``2``@]7_F^WA_I>MX?X3C>$@`()6!(1`<@4*/^'TI4GDY0```0((`7(`!
M$$2#81`L@X$0,(.A$#1\"`.F@\$0.(/A$#PX(1!`3H``(&````!@````+Y\`
M`$">_XA@````8````($^@`R`:0``2``@B7]EVWA_A.-X2``=W4O__YA(`!RE
ME"'_X'P(`J9"GP`%D\$`&)`!`"1_R`*F/]X``CO>2@2!/H`,@&D``$@`($F`
MWH`4@+Z`&(">@!Q(`![Y@`$`)(/!`!@X(0`@?`@#IDZ``""4(?_@?`@"ID*?
M``63P0`8D`$`)'_(`J:3X0`</]X``CO>2;2#_H`,@'\``$@`'_5+__^!@'\`
M`$@`'^F`_H`@@+Z`)#D```"`GH`H?.8[>$@`'T&``0`D@\$`&(/A`!PX(0`@
M?`@#IDZ``"!@````E"'?T'P(`J9"GP`%D\$@*)`!(#1_R`*FD^$@+).!(""3
MH2`D.^$`%#_>``([WDE$@2*/^)$A(!PY(```2``=-8$>@"R`WH`P.*`0`3B`
M``%\9QMX?^/[>$S&,8)(`!WU+X,``$&<`'P[@1`8?^/[>#B@$`!_A.-X2``<
MB7Q_&WE!@`!@.'\``4@`'1E\?1MY08(`&'_E^WA_A.-X2``;U3D@``!]/?FN
M@4$@'($BC_A]2DIY.2```'^CZWA`@@`L@`$@-(.!(""#H2`D@\$@*'P(`Z:#
MX2`L."$@,$Z``"`[H```2___Q$@`&OE@````E"'_X)/!`!A@0@``@\$`&#@A
M`"!+__[\8````&````"4(>^P?`@"ID*?``5]@``FD\$02)`!$%1_R`*FDT$0
M.).!$$"3X1!,D8$0*)+A$"R3`1`PDR$0-)-A$#R3H1!$/]X``GQ\&W@[WD@T
M?)\C>(!^@#@X@0`8@2*/^)$A$!PY(```3,8Q@DO_]0DX@``O?'H;>'^#XWA(
M`!QI+X,``$&>`&B`?H`\?X3C>$S&,8)+__<Q?X/C>(%!$!R!(H_X?4I*>3D@
M``!`@@'`@`$05(&!$"B"X1`L@P$0,'P(`Z:#(1`T@T$0.'V`@2"#81`\@X$0
M0(.A$$2#P1!(@^$03#@A$%!.@``@?X/C>"X:``!(`!P1@SZ`0'QX&WA_),MX
M?^/[>$@`'2U\?1MY08+_>(D]```ZX```.^```#L8``$[80`<+XD``&+W@`!!
MG@#H09(`&'^DZWA_0]-X2``9U2^#``!!G@"L?Z/K>$@`&[5]71H4B2K__R^)
M`"]`G@`H8````&````!@````8````)_J__\X8___B2K__R^)`"]!GO_P?'@:
M%"^##_]!G?[X@1Z`1(#>@$A_I^MX?XGC>#B@$``X@``!?V/;>$S&,8)(`!N1
M@[Z`#(!]``!(`!SE?V3;>#BC`4@X8``#2``<Q2^#``!`G@`<@'T``$@`',6!
M(P%852D$)G^)N`!!G@!,?R3+>#A@``!(`!PY+X,``'Q]&WA!GOZ`B3T``"^)
M``!`GO\@09(`&(">@#1_0]-X2``8\2^#``!!GO_(@[Z`-#A@``%+__]0.(``
M`7]CVWA(`!OA+X,``$">_ZB`?H`\?V3;>$S&,8)+__5I?V/;>$@`&S%+__XT
M2``8:6````"4(?_@D\$`&(DC```OB0``09X`/#E#``%(```88````(DJ```Y
M2@`!+XD``$&>`"`KB0`O0)[_[(DJ``!]0U-X.4H``2^)``!`GO_H@\$`&#@A
M`"!.@``@8````&````"4(?_@?`@"ID*?``63P0`8D^$`''_(`J9\?QMYD`$`
M)).A`!0_W@`".]Y%9$&"`'2+OP``+YT``$&>`&A(`!GU.&/__WR_&A1_GRA`
M0)P`Z'T_&*XOB0`O0)X`J'T_*%!]*0.F2```&&````!@````B24``"^)`"]`
MG@"(.*7__T(`__`KG0`O09X`&(!^@$1(`!HQ2```)&````!@````.&```D@`
M&1TL`P``08(`-#D@+@"Q(P``@`$`)(.A`!2#P0`8@^$`'#@A`"!\"`.F3H``
M(&````!@````8````(`!`"2#H0`4.&```(/!`!B#X0`<."$`('P(`Z9.@``@
M.27__W^?2$!]/RA0?2D#ID&=`+`OG___0)X`%$@``*2))0``+XD`+T&>`!0X
MI?__0@#_\'^?*$!!GO],.27__W^?2$!]/RA0?2D#ID&=`(`OG___0)X`&$@`
M`'1@````B24``"^)`"]`G@`,.*7__T(`__!\ORA0.24``BN)$`!!G?]@@'Z`
M!'_D^W@XP!``.*4``3NC``1_H^MX2``9=8`!`"1_H^MX@\$`&(.A`!2#X0`<
M."$`('P(`Z9.@``@.2```7TI`Z9+__]D.2```7TI`Z9+__^88````&````"4
M(?^P.*``(GP(`J9"GP`%D\$`2)`!`%1_R`*FD^$`3#AA`!@[X0`4/]X``CO>
M0X"!(H_XD2$`/#D@``"`GH`4.(0`#$@`%FV`?H!,3,8Q@DO_\=&`?H!03,8Q
M@DO_\<6`?H!43,8Q@DO_\;F`?H!83,8Q@DO_\:V`?H!<3,8Q@DO_\:&`?H!@
M3,8Q@DO_\96`?H`X3,8Q@DO_\8F`?H!D3,8Q@DO_\7V`?H!H3,8Q@DO_\7&`
M?H!L3,8Q@DO_\66`?H`\3,8Q@DO_\5F`?H!P3,8Q@DO_\4V`?H!T3,8Q@DO_
M\4&`?H!X?^3[>$S&,8)+_^_1?&0;>4&"`!"`?H!H3,8Q@DO_\@V`?H!\?^3[
M>$S&,8)+_^^M?&0;>4&"`!"`?H"`3,8Q@DO_\>F`?H"$?^3[>$S&,8)+_^^)
M?&0;>4&"`%"`?H`X3,8Q@DO_\<6`GH"0@'Z`7$S&,8)+__&U@4$`/($BC_A]
M2DIY.2```$""`'"``0!4@\$`2(/A`$PX(0!0?`@#IDZ``"!@````@'Z`B'_D
M^WA,QC&"2__O)7QD&WE!@@`<@'Z`9$S&,8)+__%A2___G&````!@````@)Z`
MC#B@``HX80`I2``8!2^#``!`GO]\.($`,TO__\Q(`!1!8````&````!@````
ME"'_T'P(`J9"GP`%D\$`*)/A`"Q_R`*FD`$`-#_>``([WD&4@2*/^)$A`!PY
M(```@_Z`E(!_```O@___09X`-(%!`!R!(H_X?4I*>3D@``!`@@!L@`$`-(/!
M`"B#X0`L."$`,'P(`Z9.@``@8````(!^@&0X@0`83,8Q@DO_[E4L`P``08(`
M+(DC```X8```+XD``$&>`!!I*0`P,&G__WQC21"0?P``2___F&`````X8```
MD'\``$O__XA(`!-UE"'_X'P(`J9"GP`%D\$`&)`!`"1_R`*F/]X``CO>0-1(
M`!1!2``3K2P#``!!@@`D@&,``(`!`"2#P0`8."$`('P(`Z9.@``@8````&``
M```X8```2___X&````!@````E"'_H'P(`J9"GP`%D\$`6)/A`%Q_R`*FD`$`
M9),A`$2300!(DV$`3).!`%"3H0!4/]X``CO>0'2!/H"4@4*/^)%!`#PY0```
M@4D`!(")``B`J0`,@,D`$(#I`!2!"0`8?5]3>8$I`!R100`@D($`))"A`"B0
MP0`LD.$`,)$!`#21(0`X08(`='Q[&W@[H0`@.T$`'$@``"1@````8````$@`
M$J$O@P``09X`F(?]``0OGP``09X`1']$TWA_X_MX3,8Q@DO_[.U_9-MX?'P;
M>4&"`!")7```+XH``$">_\1_X_MX3,8Q@DO_[QF'_0`$+Y\``$">_\2!(0`\
M@4*/^'TI4GDY0```0((`D(`!`&2#(0!$@T$`2(-A`$Q\"`.F@X$`4(.A`%2#
MP0!8@^$`7#@A`&!.@``@8````&````!_8]MX2``3_7QY&WA_@^-X2``3\7QY
M&A0X8P`"2``3=8$>@$"`WH!(?XGC>']GVW@XH/__.(```7QY&WA,QC&"2``4
M`7\DRWA_X_MX3,8Q@DO_[G%+__]82``1>6`````\`/__?"P+>&``?K!\(0%N
M?`@"ID*?``63S/_X?\@"II.L__20#``$.Z&!$)+L_]R3#/_@DRS_Y)-,_^B3
M;/_LDXS_\#_>``*3[/_\.]X^R)(L_\2!/H"4DDS_R'QZ&WB2;/_,DHS_T(/I
M`"R`"0`P.)U_!#[A``&!:0`T@*D`.(#)`#R`Z0!`@0D`1(%)`$B#*0`@@VD`
M)(.)`"B2K/_4@2D`3)+,_]B`?H`X@P*/^),7@0P[````D_U_(),]?PB3?7\,
MDYU_$)`=?R21?7\HD+U_+)#=?S"0_7\TD1U_%)%=?QB1/7\<3,8Q@DO_ZR5\
M?QMY08(`$(D_```OB0``0)X$X$O__/T[_7\0.WU_!'Q\&WE!@@*(?X/C>$@`
M$H548P@\.&,``4@`$@F(_```+X<``'Q[&WA!G@!`@SZ`G']_VWA@````8```
M`&````!_X_MX?R;+>#B@__\X@``!3,8Q@D@`$GV,_``!._\``B^'``!`GO_<
M@'U_("^#``!!G@!@._U_(#L]?P1(```0A'\`!"^#``!!G@!(?R3+>$S&,8)+
M_^IM?'P;>4&"_^2)/```+XD``$&>_]A+__$5+X,``$&>_\Q_@^-X2``297Q_
M&WE`@@"<8````&`````[@```.QU_"#E```!7B1`Z84J!$'U*"A1]*DH4/2G_
M_X/I?P@OGP``09X!R(D_```OB0``09X!O'_C^WA7F1`Z2__PL3N<``%_.,H4
M+X,``$">`#"'^0`$+Y\``$&>`92)/P``+XD``$&>`8A_X_MX.YP``4O_\'TO
M@P``09[_V'_C^WA(`!'-?'\;>4&"_WQ_X_MX2``1+7Q\&WA_8]MX2``1(7^<
M&A0[G`0$?X/C>$@`$*&"_H!$@3Z`H']JVWA_Y_MX@-Z`I#B@__\X@``!?'@;
M>'[HNWA,QC&"2``1)3B``<!_`\-X2``162^#__]!G@$0@WZ`#(![``!(`!)E
M?P3#>#BC`4@X8``#2``297Q_&WE!@@$L@3Z`K(#:``!_!\-X.(```8"^@,@[
M8```@&D``$S&,8)(`!&)/N$``7]CVWB#%X$,@N*/^'\8NGDZX```0(('W(%A
M``"`"P`$@BO_Q()+_\B":__,?`@#IH*+_]""J__4@LO_V(+K_]R#"__@@RO_
MY(-+_^B#:__L@XO_\(.K__2#R__X@^O__'UA6WA.@``@8````&````!(`!"A
M?'P;>4""_8"$?P`$+X,``$&>`E!_9-MX3,8Q@DO_Z&%\:1MY08+_Y(DI```O
MB0``09[_V$O__\A@````.^```$O__IQ@````8````$@`$&&!`P``+X@`$4&>
M_NB!/H"L@-H``'\'PW@X@``!@+Z`J#M@``"`:0``3,8Q@D@`$)%+__\(8```
M`&````"`>P``2``1'8$C`5A5*00F+XE``$">_L2`>P``2``1!8,C`6!(``X=
M?YD8`$">_JR`>P``2``0[8$C`5A5*07^+XD!P$">_I1_@^-X2``.Q3B=?P1\
M>QMX@'Z`Q$S&,8)+_^>1+X,``$&>`8B#F@``2``/H7QD&WA_@^-X2__R!7QY
M&WE!@@%L?R/+>$@`#O4O@P`#?'P;>$"=`#@X8__\@)Z`L'QY&A1(``SI+X,`
M`$">`"`OG``$09X%3'^9XA2)//_[+XD`+T&>!3Q@````2__X42^#``!`G@`<
M.(```'\CRWA,QC&"2``.N7QT&WE`@@$(@)Z`D(!^@&1,QC&"2__I04@`#=V#
MOH`@@-Z`O'[HNWA_!\-X.*#__SB```%\:1MX?ZKK>']CVWA,QC&"2``.D4@`
M`%!@````8````$@`#N&!(P``+XD`$4">`$Q(``V1DZ$`"#O_``&`WH#`?^K[
M>'[HNWA\:1MX?P?#>#B@__\X@``!?V/;>$S&,8)(``Y!.(`!P']CVWA(``YU
M+X/__T&>_ZQ_`\-X2``,-8!^@#A_9-MX3,8Q@DO_Z)5_8]MX2__XC4O__41@
M````2__X@7_C^WA(``Y)?'L;>$O__2PX8``-2``-.3C@`%.#GH"8?'L;>$O_
M^S1@````@SH``$O__I0XH/__.,#_[CC@``([_7_\2``,R3B@``9_Y/MX?H.C
M>$@`"XF)/7_\+XD``$">`!")/7_]+XD`0T&>!$`XX```.*```#C```!^@Z-X
M2``,C3T@9T4Y````82DC`9$=?SB1/7\\/2#OS6$IJXDY````D3U_1#T@F+IA
M*=S^D1U_0)$]?TP](!`R82E4=CD```"1/7]4/2##TF$IX?"1'7](.0```#E`
M```Y8```D1U_4)$]?UPY````.2```)$=?UB177]@D7U_9)%=?VB1?7]LD3U_
ML#I@```ZO7_\8G.``#I````[/7]P.MU_.&````!@````8````'YEFWA^I*MX
M?H.C>$@`"J5\>AMY0($!*($]?V"!77]D?TC^<"N)``!721@X?2E0%$&=`M!`
MG@`,?XI(0$&=`L2`W7]H@/U_;(!]?[!72A]^DEU_8%$*&#A5"!]^+X,``'U*
M.!1]"#$4D3U_9)$=?VB177]L09X"?"$C`$!_4=-X?YI(`$"=``A],4MX?B6+
M>'ZDJWA\>1H42``*68$]?[!],4H4+XD`0)$]?[!`GO]4?L.S>']1T%!^-8H4
M2__612^:`#]`G0!(?US3>'X_BWA_Y/MX.*``0'\CRW@[G/_`2``*$7[#LW@[
M_P!`2__6%2^<`#]!G?_<.UK_P%=)`#)76@:^.2D`0'XQ2A1_1=-X.,``2'XD
MBWA_(\MX2``+)9-=?[!^99MX?J2K>'Z#HWA(``F!?'H;>4&!_N!^@Z-X.UU_
M<$@`#0V#_7]D.4#_@(.=?VQ7Z>C^52D&OCAI``%]6DFN+X,`.$&=`>@@HP`X
M.(```'QZ&A1(``N)5X5&/E>&A#Y7A\(^5^A&/E?JA#Y7Z<(^.'U_.)B]?ZB8
MW7^IF/U_JIN=?ZN9'7^LF5U_K9D]?ZZ;_7^O2__528"]?SR`W7]$@1U_3(%=
M?U2!/7]<5*=&/E2QA#Y5&80^51K"/E5<1CY57X0^5++"/E331CY4U(0^5-7"
M/E461CY50,(^52M&/E4CA#Y5),(^FSU_Q8,^@)R;77_&FYU_R)O]?\F8_7^\
MFCU_O9I=?[Z8O7^_FGU_P)J=?\&:O7_"F-U_PYK=?\29'7_'F!U_RIE=?\N9
M?7_,F'U_S9B=?\Z9/7_/._U_T#N=?[P[77_X2```"(S\``%_X_MX?R;+>#B@
M__\X@``!._\``DS&,8)(``I%?YKX0$">_]PY8```@5Z`((#>@+@Y/7_0F7U_
M^'[HNWA_!\-X.*#__SB```%_8]MX3,8Q@D@`"@U_`\-X2``(%8!^@#A_9-MX
M3,8Q@DO_Y'5_8]MX2__T;4O_^21@````.CU__$O__<Q@````8````(%=?VR`
MW7]H,.H``7S&`91+__TX@YH`!"^<``!!GOK$?X/C>$@`"6TK@P`#0)WZM#AC
M__R`GH"T?'P:%$@`!V4O@P``0)[ZG'^9XWA+__J4(*,`0#B````[/7\X?'H:
M%$@`":%_(\MX2__3F3B@`#@X@```?T/3>$@`"8E+__X`B3U__B^)`$%`GON\
MB3U__R^)`$-`GONPB2$!$"^)`$A`GONDB2$!$2^)`$5`GON8.,#_QCC@``(X
MH/__?H.C>$@`""%_Y/MX.*``*7Z#HWA(``;A@5Z`((#>@+A_Z?MX?NB[>'\'
MPW@XH/__.(```7]CVWA,QC&"2``(V4O_^JQ(``9A8````&````!@````E"'_
ML'P(`J9"GP`%D\$`2)`!`%1_R`*FDP$`,).!`$"3X0!,DL$`*)+A`"R3(0`T
MDT$`.)-A`#R3H0!$/]X``CL!`!@[WC.T@YZ`#(!\``"!(H_XD2$`'#D@``!(
M``G%?'\;>(!\``!(``FY?P3#>(DC`&2`?H!<F3\`94S&,8)+_^!Q+`,``$&"
M`!")(P``+XD`,4&>`FQ+_^^9@'P``$@`"8&`GH#,.,``"SB@``%(``=Q@WZ`
M!"P#``!!@@#8@3L0!(%#`!`OB0`!@RH`&$"=`,0^X``@.Z```#O@``%B]P0`
M2```-&````!@````@(@`$'[#LWA(``69@3L0!"^#``!`G@"$._\``3N]``%_
MB?@`0)T`=(!\``!(``D%.,```'^EZWA_),MX2``(E7QZ&WE!@@(L@1H``(#[
M$`A7ZA`Z@2@`"'['4"Y^Z4@X+XD$`$&>_YR`?```2``(Q8":```XP``".*``
M`$@`!B5\9!MX?L.S>$@`!1F!.Q`$+X,``$&>_X0Y2?__?XKH`$&>`8"`?```
M2``(B8">@-`XP``#.*```4@`!GE\?QMY08(`,(!\``!(``AI@3\`$("^@-2`
MB0``2``%N8$_`!"!*0``@2D`"'4J`$!`@@'P@'P``$@`"#V`GH#8.,```SB@
M``%(``8M?'\;>4&"`#2`?H`\?P3#>$S&,8)+_][E?'T;>8!\``!!@@&82``(
M!8$_`!!_I>MX@(D``$@`!56`?```2``'[7Q_&WB`?```2``'X8">@-PXH``!
M2``&98"^@.!\9!MX?^/[>$@`!26`?```2``'O3D@``!_!,-XF2,`98!^@#A,
MQC&"2__>=2^#``!\?QMXD'L0#$&>`/0X@`'`?^/[>$@`!FDO@P`1?&8;>$&>
M`!`Y(P`!*XD``4&=`3B!(0`<@4*/^'TI4GDY0```0((!((`!`%2"P0`H@N$`
M+(,!`#!\"`.F@R$`-(-!`#B#80`\@X$`0(.A`$2#P0!(@^$`3#@A`%!.@``@
MB2,``2^)``!!GOV42__]C"^)``%`G?Z`.^```4@``!1@````8````&````!@
M````@'P``#O_``%(``;I?R3+>$@``[&!.Q`$?XGX`$&=_^1+__Y$8````&``
M``!@````@3L0!#E)__]_BN@`0)[^*$O__Z!@````8````&````"`>Q`(2__Q
M72^#``!\?QMXD'L0#$">_OR`?H#D3,8Q@D@`!3%@````8````&````!(``9Q
M@5L0"($_`!"`B@``@&D``$O_Y,U+__YH@'P``$@`!E&!/P`0@(D``$@`!75+
M__X`2``";8$[$`B`?H#H?^7[>(")``!,QC&"2``$U90A_^!\"`*F0I\`!9/!
M`!B3H0`4?\@"II`!`"23X0`<?'T;>#_>``([WB^T2__J)8DC```OB0``09X`
ME#E#``%\?QMX2```'&````!@````B2H``#E*``$OB0``09X`("N)`"]`GO_L
MB2H``'U?4W@Y2@`!+XD``$">_^A+_^VE+X,``$&>`"POG0``09X`)(D]```O
MB0``09X`&(">@*!_X_MX2``!W7^?&`!!G@`H@`$`)(.A`!2#P0`8@^$`'#@A
M`"!\"`.F3H``('Q_&WA+__^L@`$`)(/!`!A_H^MX@^$`'(.A`!0X(0`@?`@#
MIDO_X0````````````````"4(?_P?`@"ID*?``63P0`(D`$`%'_(`J8_W@`"
M.]XOQ($^@``OB0``09X`*(#)``!(``*1@`$`%(/!``@X(0`0?`@#IDZ``"!@
M````8````#C```!(``)M@`$`%(/!``@X(0`0?`@#IDZ``"``````E"'_T'P(
M`J9"GP`%D\$`*),A`!1_R`*FDT$`&)-A`!R3@0`@DZ$`))`!`#23X0`L?'D;
M>'R:(WA\NRMX/]X``CO>+UA+_\B9@YZ`!($^@``[O/_\?YQ(4'^<%G%!@@`X
M.^```&````!@````8````(4]``1_9=MX?T33>'\CRWA]*0.F._\``4Z`!"%_
MG/A`0)[_X(`!`#2#(0`4@T$`&(-A`!Q\"`.F@X$`((.A`"2#P0`H@^$`+#@A
M`#!.@``@E"'_\)/!``A@0@``@\$`"#@A`!!.@``@``````````"4(?_P?`@"
MID*?``63P0`(D`$`%'_(`J8_W@`".]XN@$@``,$```````````````"!?H)4
M?6D#IDZ`!"!@````@7Z"6'UI`Z9.@`0@8````(%^@EQ]:0.F3H`$(&````"!
M?H)@?6D#IDZ`!"!@````@7Z"9'UI`Z9.@`0@8````(%^@FA]:0.F3H`$(&``
M``"!?H)L?6D#IDZ`!"!@````@7Z"<'UI`Z9.@`0@8````(%^@G1]:0.F3H`$
M(&````"!?H)X?6D#IDZ`!"!@````@7Z"?'UI`Z9.@`0@8````(%^@61]:0.F
M3H`$(&````"!?H*$?6D#IDZ`!"!@````@7Z"B'UI`Z9.@`0@8````(%^@HQ]
M:0.F3H`$(&````"!?H*0?6D#IDZ`!"!@````@7Z"E'UI`Z9.@`0@8````(%^
M@IA]:0.F3H`$(&````"!?H+`?6D#IDZ`!"!@````@7Z"H'UI`Z9.@`0@8```
M`(%^@91]:0.F3H`$(&````"!?H*H?6D#IDZ`!"!@````@7Z"K'UI`Z9.@`0@
M8````(%^@K!]:0.F3H`$(&````"!?H*T?6D#IDZ`!"!@````@7Z"N'UI`Z9.
M@`0@8````(%^@KQ]:0.F3H`$(&````"!?H+`?6D#IDZ`!"!@````@7X`?'UI
M`Z9.@`0@8````(%^@LA]:0.F3H`$(&````"!?H+,?6D#IDZ`!"!@````@7Z"
MT'UI`Z9.@`0@8````(%^@M1]:0.F3H`$(&````"!?@"0?6D#IDZ`!"!@````
M@7Z"W'UI`Z9.@`0@8````(%^@N!]:0.F3H`$(&````"!?H+D?6D#IDZ`!"!@
M````@7Z"Z'UI`Z9.@`0@8````(%^@NQ]:0.F3H`$(&````"!?H+P?6D#IDZ`
M!"!@````@7Z"]'UI`Z9.@`0@8````(%^@OA]:0.F3H`$(&````"!?H+\?6D#
MIDZ`!"!@````@7Z#`'UI`Z9.@`0@8````(%^@P1]:0.F3H`$(&````"!?H,(
M?6D#IDZ`!"!@````@7Z##'UI`Z9.@`0@8````(%^@Q!]:0.F3H`$(&````"!
M?H,4?6D#IDZ`!"!@````@7Z#&'UI`Z9.@`0@8````(%^@QQ]:0.F3H`$(&``
M``"!?H,@?6D#IDZ`!"!@````@7Z#)'UI`Z9.@`0@8````(%^@RA]:0.F3H`$
M(&````"!?H,L?6D#IDZ`!"!@````@7Z#,'UI`Z9.@`0@8````(%^@S1]:0.F
M3H`$(&````"!?H,X?6D#IDZ`!"!@````@7Z#/'UI`Z9.@`0@8````(%^@T!]
M:0.F3H`$(&````"!?H-$?6D#IDZ`!"!@````@7Z#2'UI`Z9.@`0@8````(%^
M@TQ]:0.F3H`$(&````!(``$`2```_$@``/A(``#T2```\$@``.Q(``#H2```
MY$@``.!(``#<2```V$@``-1(``#02```S$@``,A(``#$2```P$@``+Q(``"X
M2```M$@``+!(``"L2```J$@``*1(``"@2```G$@``)A(``"42```D$@``(Q(
M``"(2```A$@``(!(``!\2```>$@``'1(``!P2```;$@``&A(``!D2```8$@`
M`%Q(``!82```5$@``%!(``!,2```2$@``$1(``!`2```/$@``#A(```T2```
M,$@``"Q(```H2```)&````!@````8````&````!@````8````&````!@````
M/6L``'P(`J9"GP`%.6L!#'V(`J9\"`.F?6Q84#V,``*`#*J0@8RJE'P)`Z9\
M"UH4?6!:%$Z`!"!@````8````)0A__!\"`*FD`$`%)/!``A"GP`%?\@"IH`!
M`!1\"`.F@\$`"#@A`!!.@``@``(``7!E<FQX<VDN8P```%]?14Y67U!!4E]#
M3$5!3E]?("`@("`@("`@("`@("`@`````"5S+R5S````+W!R;V,O<V5L9B]E
M>&4``$1Y;F%,;V%D97(Z.F)O;W1?1'EN84QO861E<@!);G1E<FYA;',Z.E!!
M4CHZ0D]/5`````!E>&4`+W!R;V,O)6DO)7,`+@```%!!4E]414U0`````%!!
M4E]04D]'3D%-10`````Z````+P```"5S)7,E<P``4$523#5,24(`````4$52
M3$Q)0@!015),-4]05`````!015),24\``%!!4E])3DE424%,25I%1`!005)?
M4U!!5TY%1`!005)?0TQ%04X```!005)?1$5"54<```!005)?0T%#2$4```!0
M05)?05)'0P````!005)?05)'5E\P``!005)?1TQ/0D%,7T1%0E5'`````%!!
M4E]'3$]"04Q?5$U01$E2````4$%27U1-4$1)4@``4$%27T=,3T)!3%]414U0
M`%!!4E]'3$]"04Q?0TQ%04X`````4$%27T-,14%./0``,0```%-94U1%30``
M)3`R>`````!P87(M`````"5S)7,E<R5S`````"5S.B!C<F5A=&EO;B!O9B!P
M<FEV871E('-U8F1I<F5C=&]R>2`E<R!F86EL960@*&5R<FYO/25I*0H``'!A
M<FP`````+G!A<@`````E<R5S8V%C:&4M)7,E<P``)7,E<W1E;7`M)74E<P``
M`"5S)7-T96UP+25U+25U)7,`````)7,Z('!R:79A=&4@<W5B9&ER96-T;W)Y
M("5S(&ES('5N<V%F92`H<&QE87-E(')E;6]V92!I="!A;F0@<F5T<GD@>6]U
M<B!O<&5R871I;VXI"@``05)'5@`````8````<&5R;``````P````4$%2.CI0
M86-K97(Z.E9%4E-)3TX`````,2XP,S4```!5;F%B;&4@=&\@8W)E871E(&-A
M8VAE(&1I<F5C=&]R>0`````E<SH@8W)E871I;VX@;V8@<')I=F%T92!C86-H
M92!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*`````"UE```M
M+0``55-%4@````!54T523D%-10````!414U01$E2`%1-4``O=&UP`````$Q$
M7TQ)0E)!4EE?4$%42`!,24)0051(`$Q)0E)!4EE?4$%42`````!$64Q$7TQ)
M0E)!4EE?4$%42````%-(3$E"7U!!5$@``&5V86P@)V5X96,@+W5S<B]B:6XO
M<&5R;"`@+5,@)#`@)'LQ*R(D0")])PII9B`P.R`C(&YO="!R=6YN:6YG('5N
M9&5R('-O;64@<VAE;&P*<&%C:V%G92!?7W!A<E]P;#L*;7D@*"1P87)?=&5M
M<"P@)'!R;V=N86UE+"!`=&UP9FEL92D["D5.1"![(&EF("@D14Y6>U!!4E]#
M3$5!3GTI('L*<F5Q=6ER92!&:6QE.CI496UP.PIR97%U:7)E($9I;&4Z.D)A
M<V5N86UE.PIR97%U:7)E($9I;&4Z.E-P96,["FUY("1T;W!D:7(@/2!&:6QE
M.CI"87-E;F%M93HZ9&ER;F%M92@D<&%R7W1E;7`I.PIO=71S*'%Q>U)E;6]V
M:6YG(&9I;&5S(&EN("(D<&%R7W1E;7`B?2D["D9I;&4Z.D9I;F0Z.F9I;F1D
M97!T:"AS=6(@>R`H("UD("D@/R!R;61I<B`Z('5N;&EN:R!]+"`D<&%R7W1E
M;7`I.PIR;61I<B`D<&%R7W1E;7`["FEF("@M9"`D<&%R7W1E;7`@)B8@)%Y/
M(&YE("=-4U=I;C,R)RD@>PIM>2`D=&UP(#T@;F5W($9I;&4Z.E1E;7`H"E1%
M35!,051%(#T^("=T;7!86%A86"<L"D1)4B`]/B!&:6QE.CI"87-E;F%M93HZ
M9&ER;F%M92@D=&]P9&ER*2P*4U5&1DE8(#T^("<N8VUD)RP*54Y,24Y+(#T^
M(#`L"BD["G!R:6YT("1T;7`@(B,A+V)I;B]S:`IX/3$[('=H:6QE(%L@7"1X
M("UL="`Q,"!=.R!D;PIR;2`M<F8@)R1P87)?=&5M<"<*:68@6R!<(2`M9"`G
M)'!A<E]T96UP)R!=.R!T:&5N"F)R96%K"F9I"G-L965P(#$*>#U@97AP<B!<
M)'@@*R`Q8`ID;VYE"G)M("<B("X@)'1M<"T^9FEL96YA;64@+B`B)PHB.PIC
M:&UO9"`P-S`P+"1T;7`M/F9I;&5N86UE.PIM>2`D8VUD(#T@)'1M<"T^9FEL
M96YA;64@+B`G(#XO9&5V+VYU;&P@,CXF,2`F)SL*8VQO<V4@)'1M<#L*<WES
M=&5M*"1C;60I.PIO=71S*'%Q*%-P87=N960@8F%C:V=R;W5N9"!P<F]C97-S
M('1O('!E<F9O<FT@8VQE86YU<#H@*0HN("1T;7`M/F9I;&5N86UE*3L*?0I]
M('T*0D5'24X@>PI);G1E<FYA;',Z.E!!4CHZ0D]/5"@I(&EF(&1E9FEN960@
M)DEN=&5R;F%L<SHZ4$%2.CI"3T]4.PIE=F%L('L*7W!A<E]I;FET7V5N=B@I
M.PII9B`H97AI<W1S("1%3E9[4$%27T%21U9?,'T@86YD("1%3E9[4$%27T%2
M1U9?,'T@*2!["D!!4D=6(#T@;6%P("1%3E9[(E!!4E]!4D=67R1?(GTL("@Q
M("XN("1%3E9[4$%27T%21T-]("T@,2D["B0P(#T@)$5.5GM005)?05)'5E\P
M?3L*?0IE;'-E('L*9F]R("AK97ES("5%3E8I('L*9&5L971E("1%3E9[)%]]
M(&EF("]>4$%27T%21U9?+SL*?0I]"FUY("1Q=6EE="`]("$D14Y6>U!!4E]$
M14)51WT["FUY("5#;VYF:6<@/2`H"G!A=&A?<V5P("`@(#T^("@D7D\@/7X@
M+UY-4U=I;B\@/R`G.R<@.B`G.B<I+`I?97AE("`@("`@("`]/B`H)%Y/(#U^
M("]>*#\Z35-7:6Y\3U,R?&-Y9W=I;BDO(#\@)RYE>&4G(#H@)R<I+`I?9&5L
M:6T@("`@("`]/B`H)%Y/(#U^("]>35-7:6Y\3U,R+R`_("=<7"<@.B`G+R<I
M+`HI.PI?<V5T7W!R;V=N86UE*"D["E]S971?<&%R7W1E;7`H*3L*;7D@*"1S
M=&%R=%]P;W,L("1D871A7W!O<RD["GL*;&]C86P@)%-)1WM?7U=!4DY?7WT@
M/2!S=6(@>WT["F]P96X@7T9(+"`G/"<L("1P<F]G;F%M92!O<B!L87-T.PIB
M:6YM;V1E*%]&2"D["FUY("1B=68["FUY("1S:7IE(#T@+7,@)'!R;V=N86UE
M.PIM>2`D;V9F<V5T(#T@-3$R.PIM>2`D:61X(#T@+3$["G=H:6QE("@Q*0I[
M"B1O9F9S970@/2`D<VEZ92!I9B`D;V9F<V5T(#X@)'-I>F4["G-E96L@7T9(
M+"`M)&]F9G-E="P@,B!O<B!D:64@<7%;<V5E:R!F86EL960@;VX@(B1P<F]G
M;F%M92(Z("0A73L*;7D@)&YR96%D(#T@<F5A9"!?1D@L("1B=68L("1O9F9S
M970["F1I92!Q<5MR96%D(&9A:6QE9"!O;B`B)'!R;V=N86UE(CH@)"%=('5N
M;&5S<R`D;G)E860@/3T@)&]F9G-E=#L*)&ED>"`](')I;F1E>"@D8G5F+"`B
M7&Y005(N<&U<;B(I.PIL87-T(&EF("1I9'@@/CT@,"!\?"`D;V9F<V5T(#T]
M("1S:7IE('Q\("1O9F9S970@/B`Q,C@@*B`Q,#(T.PHD;V9F<V5T("H](#([
M"GT*;&%S="!U;FQE<W,@)&ED>"`^/2`P.PHD;V9F<V5T("T]("1I9'@@+2`T
M.PIS965K(%]&2"P@+21O9F9S970L(#(["G)E860@7T9(+"`D8G5F+"`T.PIS
M965K(%]&2"P@+21O9F9S970@+2!U;G!A8VLH(DXB+"`D8G5F*2P@,CL*<F5A
M9"!?1D@L("1B=68L(#0["B1D871A7W!O<R`]("AT96QL(%]&2"D@+2`T.PIM
M>2`E<F5Q=6ER95]L:7-T.PIW:&EL92`H)&)U9B!E<2`B1DE,12(I('L*<F5A
M9"!?1D@L("1B=68L(#0["G)E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D
M8G5F*3L*;7D@)&9U;&QN86UE(#T@)&)U9CL*;W5T<RAQ<2A5;G!A8VMI;F<@
M9FEL92`B)&9U;&QN86UE(BXN+BDI.PIM>2`D8W)C(#T@*"`D9G5L;&YA;64@
M/7X@<WQ>*%MA+69<9%U[.'TI+WQ\("D@/R`D,2`Z('5N9&5F.PIM>2`H)&)A
M<V5N86UE+"`D97AT*2`]("@D8G5F(#U^(&U\*#\Z+BHO*3\H+BHI*%PN+BHI
M?"D["G)E860@7T9(+"`D8G5F+"`T.PIR96%D(%]&2"P@)&)U9BP@=6YP86-K
M*").(BP@)&)U9BD["FEF("AD969I;F5D*"1E>'0I(&%N9"`D97AT("%^("]<
M+B@_.G!M?'!L?&EX?&%L*20O:2D@>PIM>2`H)&]U="P@)&9I;&5N86UE*2`]
M(%]T96UP9FEL92@D97AT+"`D8W)C*3L*:68@*"1O=70I('L*8FEN;6]D92@D
M;W5T*3L*<')I;G0@)&]U="`D8G5F.PIC;&]S92`D;W5T.PIC:&UO9"`P-S4U
M+"`D9FEL96YA;64["GT*)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9G5L;&YA
M;65](#T@)&9I;&5N86UE.PHD4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F:6QE
M;F%M97T@/2`D9G5L;&YA;64["GT*96QS:68@*"`D9G5L;&YA;64@/7X@;7Q>
M+S]S:&QI8B]\(&%N9"!D969I;F5D("1%3E9[4$%27U1%35!]("D@>PIM>2`D
M9FEL96YA;64@/2`B)$5.5GM005)?5$5-4'TO)&)A<V5N86UE)&5X="(["F]U
M=',H(E-(3$E".B`D9FEL96YA;65<;B(I.PIO<&5N(&UY("1O=70L("<^)RP@
M)&9I;&5N86UE(&]R(&1I92`D(3L*8FEN;6]D92@D;W5T*3L*<')I;G0@)&]U
M="`D8G5F.PIC;&]S92`D;W5T.PI]"F5L<V4@>PHD<F5Q=6ER95]L:7-T>R1F
M=6QL;F%M97T@/0HD4$%2.CI(96%V>3HZ36]D=6QE0V%C:&5[)&9U;&QN86UE
M?2`]('L*8G5F(#T^("1B=68L"F-R8R`]/B`D8W)C+`IN86UE(#T^("1F=6QL
M;F%M92P*?3L*?0IR96%D(%]&2"P@)&)U9BP@-#L*?0IL;V-A;"!`24Y#(#T@
M*'-U8B!["FUY("@D<V5L9BP@)&UO9'5L92D@/2!`7SL*<F5T=7)N(&EF(')E
M9B`D;6]D=6QE(&]R("$D;6]D=6QE.PIM>2`D9FEL96YA;64@/2!D96QE=&4@
M)')E<75I<F5?;&ES='LD;6]D=6QE?2!\?"!D;R!["FUY("1K97D["F9O<F5A
M8V@@*&ME>7,@)7)E<75I<F5?;&ES="D@>PIN97AT('5N;&5S<R`O7%$D;6]D
M=6QE7$4D+SL*)&ME>2`]("1?.R!L87-T.PI]"F1E;&5T92`D<F5Q=6ER95]L
M:7-T>R1K97E](&EF(&1E9FEN960H)&ME>2D["GT@;W(@<F5T=7)N.PHD24Y#
M>R1M;V1U;&5](#T@(B]L;V%D97(O)&9I;&5N86UE+R1M;V1U;&4B.PII9B`H
M)$5.5GM005)?0TQ%04Y](&%N9"!D969I;F5D*"9)3SHZ1FEL93HZ;F5W*2D@
M>PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W7W1M<&9I;&4@;W(@9&EE("0A.PIB
M:6YM;V1E*"1F:"D["G!R:6YT("1F:"`D9FEL96YA;64M/GMB=69].PIS965K
M*"1F:"P@,"P@,"D["G)E='5R;B`D9F@["GT*96QS92!["FUY("@D;W5T+"`D
M;F%M92D@/2!?=&5M<&9I;&4H)RYP;2<L("1F:6QE;F%M92T^>V-R8WTI.PII
M9B`H)&]U="D@>PIB:6YM;V1E*"1O=70I.PIP<FEN="`D;W5T("1F:6QE;F%M
M92T^>V)U9GT["F-L;W-E("1O=70["GT*;W!E;B!M>2`D9F@L("<\)RP@)&YA
M;64@;W(@9&EE("0A.PIB:6YM;V1E*"1F:"D["G)E='5R;B`D9F@["GT*9&EE
M(")";V]T<W1R87!P:6YG(&9A:6QE9#H@8V%N;F]T(&9I;F0@)&UO9'5L92%<
M;B(["GTL($!)3D,I.PIR97%U:7)E(%A33&]A9&5R.PIR97%U:7)E(%!!4CHZ
M2&5A=GD["G)E<75I<F4@0V%R<#HZ2&5A=GD["G)E<75I<F4@17AP;W)T97(Z
M.DAE879Y.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["G)E<75I
M<F4@24\Z.D9I;&4["G=H:6QE("AM>2`D9FEL96YA;64@/2`H<V]R="!K97ES
M("5R97%U:7)E7VQI<W0I6S!=*2!["G5N;&5S<R`H)$E.0WLD9FEL96YA;65]
M(&]R("1F:6QE;F%M92`]?B`O0E-$4$%.+RD@>PII9B`H)&9I;&5N86UE(#U^
M("]<+G!M8S\D+VDI('L*<F5Q=6ER92`D9FEL96YA;64["GT*96QS92!["F1O
M("1F:6QE;F%M92!U;FQE<W,@)&9I;&5N86UE(#U^("]S:71E8W5S=&]M:7IE
M7"YP;"0O.PI]"GT*9&5L971E("1R97%U:7)E7VQI<W1[)&9I;&5N86UE?3L*
M?0IL87-T('5N;&5S<R`D8G5F(&5Q(")02UPP,#-<,#`T(CL*)'-T87)T7W!O
M<R`]("AT96QL(%]&2"D@+2`T.PI]"FUY($!P87)?87)G<SL*;7D@*"1O=70L
M("1B=6YD;&4L("1L;V=F:"P@)&-A8VAE7VYA;64I.PID96QE=&4@)$5.5GM0
M05)?05!07U)%55-%?3L@(R!S86YI=&EZ92`H4D554T4@;6%Y(&)E(&$@<V5C
M=7)I='D@<')O8FQE;2D*)'%U:65T(#T@,"!U;FQE<W,@)$5.5GM005)?1$5"
M54=].PII9B`H(21S=&%R=%]P;W,@;W(@*"1!4D=66S!=(&5Q("<M+7!A<BUO
M<'1I;VYS)R`F)B!S:&EF="DI('L*;7D@)61I<W1?8VUD(#T@<7<H"G`@("!B
M;&EB7W1O7W!A<@II("`@:6YS=&%L;%]P87(*=2`@('5N:6YS=&%L;%]P87(*
M<R`@('-I9VY?<&%R"G8@("!V97)I9GE?<&%R"BD["FEF("A`05)'5B!A;F0@
M)$%21U9;,%T@97$@)RTM<F5U<V4G*2!["G-H:69T($!!4D=6.PHD14Y6>U!!
M4E]!4%!?4D554T5](#T@<VAI9G0@0$%21U8["GT*96QS92![(",@;F]R;6%L
M('!A<FP@8F5H879I;W5R"FUY($!A9&1?=&]?:6YC.PIW:&EL92`H0$%21U8I
M('L*)$%21U9;,%T@/7X@+UXM*%M!24U/0DQB<7!I=7-4=ETI*"XJ*2\@;W(@
M;&%S=#L*:68@*"0Q(&5Q("=))RD@>PIP=7-H($!A9&1?=&]?:6YC+"`D,CL*
M?0IE;'-I9B`H)#$@97$@)TTG*2!["F5V86P@(G5S92`D,B(["GT*96QS:68@
M*"0Q(&5Q("=!)RD@>PIU;G-H:69T($!P87)?87)G<RP@)#(["GT*96QS:68@
M*"0Q(&5Q("=/)RD@>PHD;W5T(#T@)#(["GT*96QS:68@*"0Q(&5Q("=B)RD@
M>PHD8G5N9&QE(#T@)W-I=&4G.PI]"F5L<VEF("@D,2!E<2`G0B<I('L*)&)U
M;F1L92`]("=A;&PG.PI]"F5L<VEF("@D,2!E<2`G<2<I('L*)'%U:65T(#T@
M,3L*?0IE;'-I9B`H)#$@97$@)TPG*2!["F]P96X@)&QO9V9H+"`B/CXB+"`D
M,B!O<B!D:64@(EA86#H@0V%N;F]T(&]P96X@;&]G.B`D(2(["GT*96QS:68@
M*"0Q(&5Q("=4)RD@>PHD8V%C:&5?;F%M92`]("0R.PI]"G-H:69T*$!!4D=6
M*3L*:68@*&UY("1C;60@/2`D9&ES=%]C;61[)#%]*2!["F1E;&5T92`D14Y6
M>R=005)?5$5-4"=].PII;FET7VEN8R@I.PIR97%U:7)E(%!!4CHZ1&ES=#L*
M)GLB4$%2.CI$:7-T.CHD8VUD(GTH*2!U;FQE<W,@0$%21U8["B9[(E!!4CHZ
M1&ES=#HZ)&-M9")]*"1?*2!F;W(@0$%21U8["F5X:70["GT*?0IU;G-H:69T
M($!)3D,L($!A9&1?=&]?:6YC.PI]"GT*:68@*"1O=70I('L*>PIR97%U:7)E
M($E/.CI&:6QE.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*?0IM>2`D<&%R(#T@
M<VAI9G0H0$%21U8I.PIM>2`D>FEP.PII9B`H9&5F:6YE9"`D<&%R*2!["D%R
M8VAI=F4Z.EII<#HZ<V5T0VAU;FM3:7IE*#$R."HQ,#(T*3L*;W!E;B!M>2`D
M9F@L("<\)RP@)'!A<B!O<B!D:64@(D-A;FYO="!F:6YD("<D<&%R)SH@)"$B
M.PIB:6YM;V1E*"1F:"D["F)L97-S*"1F:"P@)TE/.CI&:6QE)RD["B1Z:7`@
M/2!!<F-H:79E.CI::7`M/FYE=SL**"`D>FEP+3YR96%D1G)O;49I;&5(86YD
M;&4H)&9H+"`D<&%R*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"D@*0IO<B!D
M:64@(E)E860@)R1P87(G(&5R<F]R.B`D(2(["GT*;7D@)65N=B`](&1O('L*
M:68@*"1Z:7`@86YD(&UY("1M971A(#T@)'II<"T^8V]N=&5N=',H)TU%5$$N
M>6UL)RDI('L*)&UE=&$@/7X@<R\N*EYP87(Z)"\O;7,["B1M971A(#U^(',O
M7EQ3+BHO+VUS.PHD;65T82`]?B`O7B`@*%M>.ETK*3H@*"XK*20O;6<["GT*
M?3L*;&]C86P@)"\@/2!<-#L*:68@*&1E9FEN960@)'!A<BD@>PIO<&5N(%!!
M4BP@)SPG+"`D<&%R(&]R(&1I92`B)"$Z("1P87(B.PIB:6YM;V1E*%!!4BD[
M"F1I92`B)'!A<B!I<R!N;W0@82!005(@9FEL92(@=6YL97-S(#Q005(^(&5Q
M(")02UPP,#-<,#`T(CL*?0I#<F5A=&50871H*"1O=70I(#L*;7D@)&9H(#T@
M24\Z.D9I;&4M/FYE=R@*)&]U="P*24\Z.D9I;&4Z.D]?0U)%050H*2!\($E/
M.CI&:6QE.CI/7U=23TY,62@I('P@24\Z.D9I;&4Z.D]?5%)53D,H*2P*,#<W
M-RP**2!O<B!D:64@)"$["F)I;FUO9&4H)&9H*3L*)"\@/2`H9&5F:6YE9"`D
M9&%T85]P;W,I(#\@7"1D871A7W!O<R`Z('5N9&5F.PIS965K(%]&2"P@,"P@
M,#L*;7D@)&QO861E<B`]('-C86QA<B`\7T9(/CL*:68@*"$D14Y6>U!!4E]6
M15)"051)37T@86YD("1L;V%D97(@/7X@+UXH/SHC(7Q<0')E;2DO*2!["G)E
M<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PI005(Z.D9I;'1E<CHZ4&]D
M4W1R:7`M/FYE=RT^87!P;'DH7"1L;V%D97(L("0P*0I]"F9O<F5A8V@@;7D@
M)&ME>2`H<V]R="!K97ES("5E;G8I('L*;7D@)'9A;"`]("1E;G9[)&ME>7T@
M;W(@;F5X=#L*)'9A;"`](&5V86P@)'9A;"!I9B`D=F%L(#U^("]>6R<B72\[
M"FUY("1M86=I8R`](")?7T5.5E]005)?(B`N('5C*"1K97DI("X@(E]?(CL*
M;7D@)'-E="`](")005)?(B`N('5C*"1K97DI("X@(CTD=F%L(CL*)&QO861E
M<B`]?B!S>R1M86=I8R@@*RE]>PHD;6%G:6,@+B`D<V5T("X@*"<@)R!X("AL
M96YG=&@H)#$I("T@;&5N9W1H*"1S970I*2D*?65G.PI]"B1F:"T^<')I;G0H
M)&QO861E<BD["B0O(#T@=6YD968["FEF("@D8G5N9&QE*2!["G)E<75I<F4@
M4$%2.CI(96%V>3L*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PII
M;FET7VEN8R@I.PIR97%U:7)E7VUO9'5L97,H*3L*;7D@0&EN8R`](&=R97`@
M>R`A+T)31%!!3B\@?0IG<F5P('L**"1B=6YD;&4@;F4@)W-I=&4G*2!O<@HH
M)%\@;F4@)$-O;F9I9SHZ0V]N9FEG>V%R8VAL:6)E>'!](&%N9`HD7R!N92`D
M0V]N9FEG.CI#;VYF:6=[<')I=FQI8F5X<'TI.PI]($!)3D,["FUY("5F:6QE
M<SL*)&9I;&5S>R1??2LK(&9O<B!`1'EN84QO861E<CHZ9&Q?<VAA<F5D7V]B
M:F5C=',L('9A;'5E<R`E24Y#.PIM>2`D;&EB7V5X="`]("1#;VYF:6<Z.D-O
M;F9I9WML:6)?97AT?3L*;7D@)7=R:71T96X["F9O<F5A8V@@*'-O<G0@:V5Y
M<R`E9FEL97,I('L*;7D@*"1N86UE+"`D9FEL92D["F9O<F5A8V@@;7D@)&1I
M<B`H0&EN8RD@>PII9B`H)&YA;64@/2`D4$%2.CI(96%V>3HZ1G5L;$-A8VAE
M>R1??2D@>PHD9FEL92`]("1?.PIL87-T.PI]"F5L<VEF("@O7BA<421D:7)<
M15PO*"XJ6UY#8UTI*5Q:+VDI('L**"1F:6QE+"`D;F%M92D@/2`H)#$L("0R
M*3L*;&%S=#L*?0IE;'-I9B`H;2%>+VQO861E<B];7B]=*R\H+BI;7D-C72E<
M6B$I('L*:68@*&UY("1R968@/2`D4$%2.CI(96%V>3HZ36]D=6QE0V%C:&5[
M)#%]*2!["B@D9FEL92P@)&YA;64I(#T@*"1R968L("0Q*3L*;&%S=#L*?0IE
M;'-I9B`H+68@(B1D:7(O)#$B*2!["B@D9FEL92P@)&YA;64I(#T@*"(D9&ER
M+R0Q(BP@)#$I.PIL87-T.PI]"GT*?0IN97AT('5N;&5S<R!D969I;F5D("1N
M86UE(&%N9"!N;W0@)'=R:71T96Y[)&YA;65]*RL["FYE>'0@:68@(7)E9B@D
M9FEL92D@86YD("1F:6QE(#U^("]<+EQ1)&QI8E]E>'1<120O.PIO=71S*"!J
M;VEN("(B+`IQ<2A086-K:6YG("(I+"!R968@)&9I;&4@/R`D9FEL92T^>VYA
M;65](#H@)&9I;&4L"G%Q*"(N+BXI"BD["FUY("1C;VYT96YT.PII9B`H<F5F
M*"1F:6QE*2D@>PHD8V]N=&5N="`]("1F:6QE+3Y[8G5F?3L*?0IE;'-E('L*
M;W!E;B!&24Q%+"`G/"<L("1F:6QE(&]R(&1I92`B0V%N)W0@;W!E;B`D9FEL
M93H@)"$B.PIB:6YM;V1E*$9)3$4I.PHD8V]N=&5N="`](#Q&24Q%/CL*8VQO
M<V4@1DE,13L*4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YN97<M/F%P<&QY*%PD
M8V]N=&5N="P@)&9I;&4I"FEF("$D14Y6>U!!4E]615)"051)37T@86YD("1N
M86UE(#U^("]<+B@_.G!M?&EX?&%L*20O:3L*4$%2.CI&:6QT97(Z.E!A=&-H
M0V]N=&5N="T^;F5W+3YA<'!L>2A<)&-O;G1E;G0L("1F:6QE+"`D;F%M92D[
M"GT*;W5T<RAQ<2A7<FET=&5N(&%S("(D;F%M92(I*3L*)&9H+3YP<FEN="@B
M1DE,12(I.PHD9F@M/G!R:6YT*'!A8VLH)TXG+"!L96YG=&@H)&YA;64I("L@
M.2DI.PHD9F@M/G!R:6YT*'-P<FEN=&8H"B(E,#AX+R5S(BP@07)C:&EV93HZ
M6FEP.CIC;VUP=71E0U)#,S(H)&-O;G1E;G0I+"`D;F%M90HI*3L*)&9H+3YP
M<FEN="AP86-K*"=.)RP@;&5N9W1H*"1C;VYT96YT*2DI.PHD9F@M/G!R:6YT
M*"1C;VYT96YT*3L*?0I]"B1Z:7`M/G=R:71E5&]&:6QE2&%N9&QE*"1F:"D@
M:68@)'II<#L*)&-A8VAE7VYA;64@/2!S=6)S='(@)&-A8VAE7VYA;64L(#`L
M(#0P.PII9B`H(21C86-H95]N86UE(&%N9"!M>2`D;71I;64@/2`H<W1A="@D
M;W5T*2E;.5TI('L*;7D@)&-T>"`](&5V86P@>R!R97%U:7)E($1I9V5S=#HZ
M4TA!.R!$:6=E<W0Z.E-(02T^;F5W*#$I('T*?'P@979A;"![(')E<75I<F4@
M1&EG97-T.CI32$$Q.R!$:6=E<W0Z.E-(03$M/FYE=R!]"GQ\(&5V86P@>R!R
M97%U:7)E($1I9V5S=#HZ340U.R!$:6=E<W0Z.DU$-2T^;F5W('T["FUY("1S
M:&%?=F5R<VEO;B`](&5V86P@>R`D1&EG97-T.CI32$$Z.E9%4E-)3TX@?2!\
M?"`P.PII9B`H)'-H85]V97)S:6]N(&5Q("<U+C,X)R!O<B`D<VAA7W9E<G-I
M;VX@97$@)S4N,SDG*2!["B1C='@M/F%D9&9I;&4H)&]U="P@(F(B*2!I9B`H
M)&-T>"D["GT*96QS92!["FEF("@D8W1X(&%N9"!O<&5N*&UY("1F:"P@(CPD
M;W5T(BDI('L*8FEN;6]D92@D9F@I.PHD8W1X+3YA9&1F:6QE*"1F:"D["F-L
M;W-E*"1F:"D["GT*?0HD8V%C:&5?;F%M92`]("1C='@@/R`D8W1X+3YH97AD
M:6=E<W0@.B`D;71I;64["GT*)&-A8VAE7VYA;64@+CT@(EPP(B!X("@T,2`M
M(&QE;F=T:"`D8V%C:&5?;F%M92D["B1C86-H95]N86UE("X](")#04-(12([
M"B1F:"T^<')I;G0H)&-A8VAE7VYA;64I.PHD9F@M/G!R:6YT*'!A8VLH)TXG
M+"`D9F@M/G1E;&P@+2!L96YG=&@H)&QO861E<BDI*3L*)&9H+3YP<FEN="@B
M7&Y005(N<&U<;B(I.PHD9F@M/F-L;W-E.PIC:&UO9"`P-S4U+"`D;W5T.PIE
M>&ET.PI]"GL*;&%S="!U;FQE<W,@9&5F:6YE9"`D<W1A<G1?<&]S.PI?9FEX
M7W!R;V=N86UE*"D["G)E<75I<F4@4$%2.PI005(Z.DAE879Y.CI?:6YI=%]D
M>6YA;&]A9&5R*"D["GL*<F5Q=6ER92!&:6QE.CI&:6YD.PIR97%U:7)E($%R
M8VAI=F4Z.EII<#L*?0IM>2`D>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["FUY
M("1F:"`]($E/.CI&:6QE+3YN97<["B1F:"T^9F1O<&5N*&9I;&5N;RA?1D@I
M+"`G<B<I(&]R(&1I92`B)"$Z("1`(CL*)'II<"T^<F5A9$9R;VU&:6QE2&%N
M9&QE*"1F:"P@)'!R;V=N86UE*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"D@
M;W(@9&EE("(D(3H@)$`B.PIP=7-H($!005(Z.DQI8D-A8VAE+"`D>FEP.PHD
M4$%2.CI,:6)#86-H97LD<')O9VYA;65](#T@)'II<#L*)'%U:65T(#T@(21%
M3E9[4$%27T1%0E5'?3L*;W5T<RAQ<2A<)$5.5GM005)?5$5-4'T@/2`B)$5.
M5GM005)?5$5-4'TB*2D["FEF("AD969I;F5D("1%3E9[4$%27U1%35!]*2![
M(",@<VAO=6QD(&)E('-E="!A="!T:&ES('!O:6YT(0IF;W)E86-H(&UY("1M
M96UB97(@*"`D>FEP+3YM96UB97)S("D@>PIN97AT(&EF("1M96UB97(M/FES
M1&ER96-T;W)Y.PIM>2`D;65M8F5R7VYA;64@/2`D;65M8F5R+3YF:6QE3F%M
M93L*;F5X="!U;FQE<W,@)&UE;6)E<E]N86UE(#U^(&U["EX*+S]S:&QI8B\*
M*#\Z)$-O;F9I9SHZ0V]N9FEG>W9E<G-I;VY]+RD_"B@_.B1#;VYF:6<Z.D-O
M;F9I9WMA<F-H;F%M97TO*3\**%M>+UTK*0HD"GUX.PIM>2`D97AT<F%C=%]N
M86UE(#T@)#$["FUY("1D97-T7VYA;64@/2!&:6QE.CI3<&5C+3YC871F:6QE
M*"1%3E9[4$%27U1%35!]+"`D97AT<F%C=%]N86UE*3L*:68@*"UF("1D97-T
M7VYA;64@)B8@+7,@7R`]/2`D;65M8F5R+3YU;F-O;7!R97-S9613:7IE*"DI
M('L*;W5T<RAQ<2A3:VEP<&EN9R`B)&UE;6)E<E]N86UE(B!S:6YC92!I="!A
M;')E861Y(&5X:7-T<R!A="`B)&1E<W1?;F%M92(I*3L*?2!E;'-E('L*;W5T
M<RAQ<2A%>'1R86-T:6YG("(D;65M8F5R7VYA;64B('1O("(D9&5S=%]N86UE
M(BDI.PHD;65M8F5R+3YE>'1R86-T5&]&:6QE3F%M960H)&1E<W1?;F%M92D[
M"F-H;6]D*#`U-34L("1D97-T7VYA;64I(&EF("1>3R!E<2`B:'!U>"(["GT*
M?0I]"GT*=6YL97-S("@D4$%2.CI,:6)#86-H97LD<')O9VYA;65]*2!["F1I
M92`\/"`B+B(@=6YL97-S($!!4D=6.PI5<V%G93H@)#`@6R`M06QI8BYP87(@
M72!;("U)9&ER(%T@6R`M36UO9'5L92!=(%L@<W)C+G!A<B!=(%L@<')O9W)A
M;2YP;"!="B0P(%L@+4)\+6(@72!;+4]O=71F:6QE72!S<F,N<&%R"BX*)$5.
M5GM005)?4%)/1TY!345](#T@)'!R;V=N86UE(#T@)#`@/2!S:&EF="A`05)'
M5BD["GT*<W5B($-R96%T95!A=&@@>PIM>2`H)&YA;64I(#T@0%\["G)E<75I
M<F4@1FEL93HZ0F%S96YA;64["FUY("@D8F%S96YA;64L("1P871H+"`D97AT
M*2`]($9I;&4Z.D)A<V5N86UE.CIF:6QE<&%R<V4H)&YA;64L("@G7"XN*B<I
M*3L*<F5Q=6ER92!&:6QE.CI0871H.PI&:6QE.CI0871H.CIM:W!A=&@H)'!A
M=&@I('5N;&5S<R@M92`D<&%T:"D[(",@;6MP871H(&1I97,@=VET:"!E<G)O
M<@I]"G-U8B!R97%U:7)E7VUO9'5L97,@>PIR97%U:7)E(&QI8CL*<F5Q=6ER
M92!$>6YA3&]A9&5R.PIR97%U:7)E(&EN=&5G97(["G)E<75I<F4@<W1R:6-T
M.PIR97%U:7)E('=A<FYI;F=S.PIR97%U:7)E('9A<G,["G)E<75I<F4@0V%R
M<#L*<F5Q=6ER92!#87)P.CI(96%V>3L*<F5Q=6ER92!%<G)N;SL*<F5Q=6ER
M92!%>'!O<G1E<CHZ2&5A=GD["G)E<75I<F4@17AP;W)T97(["G)E<75I<F4@
M1F-N=&P["G)E<75I<F4@1FEL93HZ5&5M<#L*<F5Q=6ER92!&:6QE.CI3<&5C
M.PIR97%U:7)E(%A33&]A9&5R.PIR97%U:7)E($-O;F9I9SL*<F5Q=6ER92!)
M3SHZ2&%N9&QE.PIR97%U:7)E($E/.CI&:6QE.PIR97%U:7)E($-O;7!R97-S
M.CI:;&EB.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*<F5Q=6ER92!005(["G)E
M<75I<F4@4$%2.CI(96%V>3L*<F5Q=6ER92!005(Z.D1I<W0["G)E<75I<F4@
M4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0
M871C:$-O;G1E;G0["G)E<75I<F4@871T<FEB=71E<SL*979A;"![(')E<75I
M<F4@0W=D('T["F5V86P@>R!R97%U:7)E(%=I;C,R('T["F5V86P@>R!R97%U
M:7)E(%-C86QA<CHZ571I;"!].PIE=F%L('L@<F5Q=6ER92!!<F-H:79E.CI5
M;GII<#HZ0G5R<W0@?3L*979A;"![(')E<75I<F4@5&EE.CI(87-H.CI.86UE
M9$-A<'1U<F4@?3L*979A;"![(')E<75I<F4@4&5R;$E/.R!R97%U:7)E(%!E
M<FQ)3SHZ<V-A;&%R('T["F5V86P@>R!R97%U:7)E('5T9C@@?3L*?0IS=6(@
M7W-E=%]P87)?=&5M<"!["FEF("AD969I;F5D("1%3E9[4$%27U1%35!](&%N
M9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK*2\I('L*)'!A<E]T96UP(#T@)#$[
M"G)E='5R;CL*?0IF;W)E86-H(&UY("1P871H("@**&UA<"`D14Y6>R1??2P@
M<7<H(%!!4E]435!$25(@5$U01$E2(%1%35!$25(@5$5-4"!435`@*2DL"G%W
M*"!#.EQ<5$5-4"`O=&UP("X@*0HI('L*;F5X="!U;FQE<W,@9&5F:6YE9"`D
M<&%T:"!A;F0@+60@)'!A=&@@86YD("UW("1P871H.PIM>2`D=7-E<FYA;64[
M"FUY("1P=W5I9#L*979A;"![*"1P=W5I9"D@/2!G971P=W5I9"@D/BD@:68@
M9&5F:6YE9"`D/CM].PII9B`H(&1E9FEN960H)E=I;C,R.CI,;V=I;DYA;64I
M("D@>PHD=7-E<FYA;64@/2`F5VEN,S(Z.DQO9VEN3F%M93L*?0IE;'-I9B`H
M9&5F:6YE9"`D<'=U:60I('L*)'5S97)N86UE(#T@)'!W=6ED.PI]"F5L<V4@
M>PHD=7-E<FYA;64@/2`D14Y6>U5315).04U%?2!\?"`D14Y6>U5315)]('Q\
M("=365-414TG.PI]"B1U<V5R;F%M92`]?B!S+UQ7+U\O9SL*;7D@)'-T;7!D
M:7(@/2`B)'!A=&@D0V]N9FEG>U]D96QI;7UP87(M(BYU;G!A8VLH(D@J(BP@
M)'5S97)N86UE*3L*;6MD:7(@)'-T;7!D:7(L(#`W-34["FEF("@A)$5.5GM0
M05)?0TQ%04Y](&%N9"!M>2`D;71I;64@/2`H<W1A="@D<')O9VYA;64I*5LY
M72D@>PIO<&5N("AM>2`D9F@L("(\(BX@)'!R;V=N86UE*3L*<V5E:R`D9F@L
M("TQ."P@,CL*<WES<F5A9"`D9F@L(&UY("1B=68L(#8["FEF("@D8G5F(&5Q
M(")<,$-!0TA%(BD@>PIS965K("1F:"P@+34X+"`R.PIS>7-R96%D("1F:"P@
M)&)U9BP@-#$["B1B=68@/7X@<R]<,"\O9SL*)'-T;7!D:7(@+CT@(B1#;VYF
M:6=[7V1E;&EM?6-A8VAE+2(@+B`D8G5F.PI]"F5L<V4@>PIM>2`D8W1X(#T@
M979A;"![(')E<75I<F4@1&EG97-T.CI32$$[($1I9V5S=#HZ4TA!+3YN97<H
M,2D@?0I\?"!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(03$[($1I9V5S=#HZ
M4TA!,2T^;F5W('T*?'P@979A;"![(')E<75I<F4@1&EG97-T.CI-1#4[($1I
M9V5S=#HZ340U+3YN97<@?3L*;7D@)'-H85]V97)S:6]N(#T@979A;"![("1$
M:6=E<W0Z.E-(03HZ5D524TE/3B!]('Q\(#`["FEF("@D<VAA7W9E<G-I;VX@
M97$@)S4N,S@G(&]R("1S:&%?=F5R<VEO;B!E<2`G-2XS.2<I('L*)&-T>"T^
M861D9FEL92@D<')O9VYA;64L(")B(BD@:68@*"1C='@I.PI]"F5L<V4@>PII
M9B`H)&-T>"!A;F0@;W!E;BAM>2`D9F@L("(\)'!R;V=N86UE(BDI('L*8FEN
M;6]D92@D9F@I.PHD8W1X+3YA9&1F:6QE*"1F:"D["F-L;W-E*"1F:"D["GT*
M?0HD<W1M<&1I<B`N/2`B)$-O;F9I9WM?9&5L:6U]8V%C:&4M(B`N("@@)&-T
M>"`_("1C='@M/FAE>&1I9V5S="`Z("1M=&EM92`I.PI]"F-L;W-E*"1F:"D[
M"GT*96QS92!["B1%3E9[4$%27T-,14%.?2`](#$["B1S=&UP9&ER("X]("(D
M0V]N9FEG>U]D96QI;7UT96UP+20D(CL*?0HD14Y6>U!!4E]414U0?2`]("1S
M=&UP9&ER.PIM:V1I<B`D<W1M<&1I<BP@,#<U-3L*;&%S=#L*?0HD<&%R7W1E
M;7`@/2`D,2!I9B`D14Y6>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@
M/7X@+R@N*RDO.PI]"G-U8B!?=&5M<&9I;&4@>PIM>2`H)&5X="P@)&-R8RD@
M/2!`7SL*;7D@*"1F:"P@)&9I;&5N86UE*3L*)&9I;&5N86UE(#T@(B1P87)?
M=&5M<"\D8W)C)&5X="(["FEF("@D14Y6>U!!4E]#3$5!3GTI('L*=6YL:6YK
M("1F:6QE;F%M92!I9B`M92`D9FEL96YA;64["G!U<V@@0'1M<&9I;&4L("1F
M:6QE;F%M93L*?0IE;'-E('L*<F5T=7)N("AU;F1E9BP@)&9I;&5N86UE*2!I
M9B`H+7(@)&9I;&5N86UE*3L*?0IO<&5N("1F:"P@)SXG+"`D9FEL96YA;64@
M;W(@9&EE("0A.PIB:6YM;V1E*"1F:"D["G)E='5R;B@D9F@L("1F:6QE;F%M
M92D["GT*<W5B(%]S971?<')O9VYA;64@>PII9B`H9&5F:6YE9"`D14Y6>U!!
M4E]04D]'3D%-17T@86YD("1%3E9[4$%27U!23T=.04U%?2`]?B`O*"XK*2\I
M('L*)'!R;V=N86UE(#T@)#$["GT*)'!R;V=N86UE('Q\/2`D,#L*:68@*"1%
M3E9[4$%27U1%35!](&%N9"!I;F1E>"@D<')O9VYA;64L("1%3E9[4$%27U1%
M35!]*2`^/2`P*2!["B1P<F]G;F%M92`]('-U8G-T<B@D<')O9VYA;64L(')I
M;F1E>"@D<')O9VYA;64L("1#;VYF:6=[7V1E;&EM?2D@*R`Q*3L*?0II9B`H
M(21%3E9[4$%27U!23T=.04U%?2!O<B!I;F1E>"@D<')O9VYA;64L("1#;VYF
M:6=[7V1E;&EM?2D@/CT@,"D@>PII9B`H;W!E;B!M>2`D9F@L("<\)RP@)'!R
M;V=N86UE*2!["G)E='5R;B!I9B`M<R`D9F@["GT*:68@*"US("(D<')O9VYA
M;64D0V]N9FEG>U]E>&5](BD@>PHD<')O9VYA;64@+CT@)$-O;F9I9WM?97AE
M?3L*<F5T=7)N.PI]"GT*9F]R96%C:"!M>2`D9&ER("AS<&QI="`O7%$D0V]N
M9FEG>W!A=&A?<V5P?5Q%+RP@)$5.5GM0051(?2D@>PIN97AT(&EF(&5X:7-T
M<R`D14Y6>U!!4E]414U0?2!A;F0@)&1I<B!E<2`D14Y6>U!!4E]414U0?3L*
M)&1I<B`]?B!S+UQ1)$-O;F9I9WM?9&5L:6U]7$4D+R\["B@H)'!R;V=N86UE
M(#T@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64D0V]N9FEG>U]E>&5]
M(BDL(&QA<W0I"FEF("US("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE
M)$-O;F9I9WM?97AE?2(["B@H)'!R;V=N86UE(#T@(B1D:7(D0V]N9FEG>U]D
M96QI;7TD<')O9VYA;64B*2P@;&%S="D*:68@+7,@(B1D:7(D0V]N9FEG>U]D
M96QI;7TD<')O9VYA;64B.PI]"GT*<W5B(%]F:7A?<')O9VYA;64@>PHD,"`]
M("1P<F]G;F%M92!\?#T@)$5.5GM005)?4%)/1TY!345].PII9B`H:6YD97@H
M)'!R;V=N86UE+"`D0V]N9FEG>U]D96QI;7TI(#P@,"D@>PHD<')O9VYA;64@
M/2`B+B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M92(["GT*;7D@)'!W9"`]("AD
M969I;F5D("9#=V0Z.F=E=&-W9"D@/R!#=V0Z.F=E=&-W9"@I"CH@*"AD969I
M;F5D("97:6XS,CHZ1V5T0W=D*2`_(%=I;C,R.CI'971#=V0H*2`Z(&!P=V1@
M*3L*8VAO;7`H)'!W9"D["B1P<F]G;F%M92`]?B!S+UXH/SU<+EPN/UQ1)$-O
M;F9I9WM?9&5L:6U]7$4I+R1P=V0D0V]N9FEG>U]D96QI;7TO.PHD14Y6>U!!
M4E]04D]'3D%-17T@/2`D<')O9VYA;64["GT*<W5B(%]P87)?:6YI=%]E;G8@
M>PII9B`H("1%3E9[4$%27TE.251)04Q)6D5$?2LK(#T](#$@*2!["G)E='5R
M;CL*?2!E;'-E('L*)$5.5GM005)?24Y)5$E!3$E:141](#T@,CL*?0IF;W(@
M*'%W*"!34$%73D5$(%1%35`@0TQ%04X@1$5"54<@0T%#2$4@4%)/1TY!344@
M05)'0R!!4D=67S`@*2`I('L*9&5L971E("1%3E9[)U!!4E\G+B1??3L*?0IF
M;W(@*'%W+R!435!$25(@5$5-4"!#3$5!3B!$14)51R`O*2!["B1%3E9[)U!!
M4E\G+B1??2`]("1%3E9[)U!!4E]'3$]"04Q?)RXD7WT@:68@97AI<W1S("1%
M3E9[)U!!4E]'3$]"04Q?)RXD7WT["GT*;7D@)'!A<E]C;&5A;B`](")?7T5.
M5E]005)?0TQ%04Y?7R`@("`@("`@("`@("`@("(["FEF("@D14Y6>U!!4E]4
M14U0?2D@>PID96QE=&4@)$5.5GM005)?0TQ%04Y].PI]"F5L<VEF("@A97AI
M<W1S("1%3E9[4$%27T=,3T)!3%]#3$5!3GTI('L*;7D@)'9A;'5E(#T@<W5B
M<W1R*"1P87)?8VQE86XL(#$R("L@;&5N9W1H*")#3$5!3B(I*3L*)$5.5GM0
M05)?0TQ%04Y](#T@)#$@:68@)'9A;'5E(#U^("]>4$%27T-,14%./2A<4RLI
M+SL*?0I]"G-U8B!O=71S('L*<F5T=7)N(&EF("1Q=6EE=#L*:68@*"1L;V=F
M:"D@>PIP<FEN="`D;&]G9F@@(D!?7&XB.PI]"F5L<V4@>PIP<FEN="`B0%]<
M;B(["GT*?0IS=6(@:6YI=%]I;F,@>PIR97%U:7)E($-O;F9I9SL*<'5S:"!`
M24Y#+"!G<F5P(&1E9FEN960L(&UA<"`D0V]N9FEG.CI#;VYF:6=[)%]]+"!Q
M=R@*87)C:&QI8F5X<"!P<FEV;&EB97AP('-I=&5A<F-H97AP('-I=&5L:6)E
M>'`*=F5N9&]R87)C:&5X<"!V96YD;W)L:6)E>'`**3L*?0IP86-K86=E(&UA
M:6X["G)E<75I<F4@4$%2.PIU;G-H:69T($!)3D,L(%PF4$%2.CIF:6YD7W!A
M<CL*4$%2+3YI;7!O<G0H0'!A<E]A<F=S*3L*9&EE('%Q*'!A<BYP;#H@0V%N
M)W0@;W!E;B!P97)L('-C<FEP="`B)'!R;V=N86UE(CH@3F\@<W5C:"!F:6QE
M(&]R(&1I<F5C=&]R>5QN*0IU;FQE<W,@+64@)'!R;V=N86UE.PID;R`D<')O
M9VYA;64["D-/4D4Z.F5X:70H)#$I(&EF("@D0"`]?B]>7U1+7T58251?7"@H
M7&0K*5PI+RD["F1I92`D0"!I9B`D0#L*?3L*)#HZ7U]%4E)/4B`]("1`(&EF
M("1`.PI]"D-/4D4Z.F5X:70H)#$I(&EF("@D.CI?7T524D]2(#U^+UY?5$M?
M15A)5%]<*"A<9"LI7"DO*3L*9&EE("0Z.E]?15)23U(@:68@)#HZ7U]%4E)/
M4CL*,3L*7U]%3D1?7PH`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````$````!
M`````0```=\````!```!Z@````$```'T`````0```D,````!```#IP````P`
M`!<\````#0``5*`````9``'\@````!L````$````&@`!_(0````<````!&__
M_O4```&(````!0``".0````&```"9`````H```42````"P```!`````5````
M``````,``?\$`````@```O0````4````!P```!<``!1(<``````!_O@````'
M```/:`````@```?4````"0````P````8`````&____L(```!;____@``#LAO
M____`````F____````WV;___^0```%L`````````````````````````````
M```````````````````````````````!_<P`````````````4V```%-D``!3
M:```4VP``%-P``!3=```4W@``%-\``!3@```4X0``%.(``!3C```4Y```%.4
M``!3F```4YP``%.@``!3I```4Z@``%.L``!3L```4[0``%.X``!3O```4\``
M`%/$``!3R```4\P``%/0``!3U```4]@``%/<``!3X```4^0``%/H``!3[```
M4_```%/T``!3^```4_P``%0```!4!```5`@``%0,``!4$```5!0``%08``!4
M'```5"```%0D``!4*```5"P``%0P``!4-```5#@``%0\``!40```5$0``%1(
M``!43```5%```%14``!46````````````````````````````````/____\`
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````$=#0SH@*$1E8FEA
M;B`V+C(N,"TT*2`V+C(N,"`R,#$V,#DQ-```+G-H<W1R=&%B`"YI;G1E<G``
M+FYO=&4N04))+71A9P`N;F]T92YG;G4N8G5I;&0M:60`+F=N=2YH87-H`"YD
M>6YS>6T`+F1Y;G-T<@`N9VYU+G9E<G-I;VX`+F=N=2YV97)S:6]N7W(`+G)E
M;&$N9'EN`"YR96QA+G!L=``N:6YI=``N=&5X=``N9FEN:0`N<F]D871A`"YE
M:%]F<F%M90`N:6YI=%]A<G)A>0`N9FEN:5]A<G)A>0`N:F-R`"YG;W0R`"YD
M>6YA;6EC`"YG;W0`+F1A=&$`+G-D871A`"YB<W,`+F-O;6UE;G0`````````
M```````````````````````````````````````````````````+`````0``
M``(```$T```!-`````T```````````````$`````````$P````<````"```!
M1````40````@```````````````$`````````"$````'`````@```60```%D
M````)```````````````!``````````T;___]@````(```&(```!B````-P`
M```%``````````0````$````/@````L````"```"9````F0```:`````!@``
M``(````$````$````$8````#`````@``".0```CD```%$@``````````````
M`0````````!.;____P````(```WV```-]@```-`````%``````````(````"
M````6V____X````"```.R```#L@```"@````!@````(````$`````````&H`
M```$`````@``#V@```]H```$X`````4`````````!`````P```!T````!```
M`$(``!1(```42````O0````%````%@````0````,````?@````$````&```7
M/```%SP```!$```````````````$`````````(0````!````!@``%X```!>`
M```](```````````````(`````````"*`````0````8``%2@``!4H````"P`
M``````````````0`````````D`````$````"``!4S```5,P``$$T````````
M```````$`````````)@````!`````@``E@```)8`````!```````````````
M!`````````"B````#@````,``?R```#\@`````0```````````````0````$
M````K@````\````#``'\A```_(0````$```````````````$````!````+H`
M```!`````P`!_(@``/R(````!```````````````!`````````"_`````0``
M``,``?R,``#\C````4````````````````$`````````Q0````8````#``']
MS```_<P```$H````!@`````````$````"````,X````!`````P`!_O0``/[T
M````$```````````````!`````0```!Y`````0````,``?\$``#_!````/P`
M``````````````0`````````TP````$````#``(````!``````!H````````
M```````$`````````-D````!`````P`"`&@``0!H````!```````````````
M!`````````#@````"`````,``@!L``$`;```$!@```````````````0`````
M````Y0````$````P```````!`&P````E```````````````!`````0````$`
C```#`````````````0"1````[@```````````````0``````
